/* add-persona.c generated by valac 0.26.2.1-1f25, the Vala compiler
 * generated from add-persona.vala, do not modify */

/*
 * Copyright (C) 2011 Collabora Ltd.
 *
 * This library is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License as published by
 * the Free Software Foundation, either version 2.1 of the License, or
 * (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public License
 * along with this library.  If not, see <http://www.gnu.org/licenses/>.
 *
 * Authors: Raul Gutierrez Segales <raul.gutierrez.segales@collabora.co.uk>
 *
 */

#include <glib.h>
#include <glib-object.h>
#include <tracker-test.h>
#include <folks/folks.h>
#include <stdlib.h>
#include <string.h>
#include <gio/gio.h>
#include <folks/folks-tracker.h>
#include <folks-test.h>
#include <gee.h>


#define TYPE_ADD_PERSONA_TESTS (add_persona_tests_get_type ())
#define ADD_PERSONA_TESTS(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_ADD_PERSONA_TESTS, AddPersonaTests))
#define ADD_PERSONA_TESTS_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_ADD_PERSONA_TESTS, AddPersonaTestsClass))
#define IS_ADD_PERSONA_TESTS(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_ADD_PERSONA_TESTS))
#define IS_ADD_PERSONA_TESTS_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_ADD_PERSONA_TESTS))
#define ADD_PERSONA_TESTS_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_ADD_PERSONA_TESTS, AddPersonaTestsClass))

typedef struct _AddPersonaTests AddPersonaTests;
typedef struct _AddPersonaTestsClass AddPersonaTestsClass;
typedef struct _AddPersonaTestsPrivate AddPersonaTestsPrivate;
#define _g_main_loop_unref0(var) ((var == NULL) ? NULL : (var = (g_main_loop_unref (var), NULL)))
#define _g_object_unref0(var) ((var == NULL) ? NULL : (var = (g_object_unref (var), NULL)))
#define _g_free0(var) (var = (g_free (var), NULL))
#define _g_hash_table_unref0(var) ((var == NULL) ? NULL : (var = (g_hash_table_unref (var), NULL)))
#define _g_date_time_unref0(var) ((var == NULL) ? NULL : (var = (g_date_time_unref (var), NULL)))
#define _g_list_free0(var) ((var == NULL) ? NULL : (var = (g_list_free (var), NULL)))
#define _g_error_free0(var) ((var == NULL) ? NULL : (var = (g_error_free (var), NULL)))
typedef struct _AddPersonaTestsTestAddPersonaAsyncData AddPersonaTestsTestAddPersonaAsyncData;
#define __vala_GValue_free0(var) ((var == NULL) ? NULL : (var = (_vala_GValue_free (var), NULL)))
typedef struct _AddPersonaTestsAddPersonaData AddPersonaTestsAddPersonaData;
#define _vala_assert(expr, msg) if G_LIKELY (expr) ; else g_assertion_message_expr (G_LOG_DOMAIN, __FILE__, __LINE__, G_STRFUNC, msg);

struct _AddPersonaTests {
	TrackerTestTestCase parent_instance;
	AddPersonaTestsPrivate * priv;
};

struct _AddPersonaTestsClass {
	TrackerTestTestCaseClass parent_class;
};

struct _AddPersonaTestsPrivate {
	GMainLoop* _main_loop;
	FolksIndividualAggregator* _aggregator;
	gchar* _persona_fullname;
	gchar* _persona_nickname;
	gchar* _family_name;
	gchar* _given_name;
	GHashTable* _properties_found;
	gchar* _persona_iid;
	GLoadableIcon* _avatar;
	gchar* _birthday;
	GDateTime* _bday;
	gchar* _email_1;
	gchar* _email_2;
	gchar* _im_addr_1;
	gchar* _im_addr_2;
	gchar* _note_1;
	gchar* _phone_1;
	gchar* _phone_2;
	gchar* _title_1;
	gchar* _organisation_1;
	gchar* _role_1;
	FolksPostalAddressFieldDetails* _postal_address_fd;
	gchar* _po_box;
	gchar* _locality;
	gchar* _postal_code;
	gchar* _street;
	gchar* _extension;
	gchar* _country;
	gchar* _region;
	gchar* _url_1;
	gchar* _url_2;
	TrfPersonaStore* _pstore;
	gboolean _added_persona;
};

struct _AddPersonaTestsTestAddPersonaAsyncData {
	int _state_;
	GObject* _source_object_;
	GAsyncResult* _res_;
	GSimpleAsyncResult* _async_result;
	AddPersonaTests* self;
	FolksBackendStore* store;
	FolksBackendStore* _tmp0_;
	FolksIndividualAggregator* _tmp1_;
	FolksIndividualAggregator* _tmp2_;
	FolksIndividualAggregator* _tmp3_;
	GeeIterator* _backend_it;
	GeeMap* _tmp4_;
	GeeMap* _tmp5_;
	GeeCollection* _tmp6_;
	GeeCollection* _tmp7_;
	GeeCollection* _tmp8_;
	GeeIterator* _tmp9_;
	GeeIterator* _tmp10_;
	GeeIterator* _tmp11_;
	gboolean _tmp12_;
	FolksBackend* backend;
	GeeIterator* _tmp13_;
	gpointer _tmp14_;
	FolksBackend* _tmp15_;
	GeeMap* _tmp16_;
	GeeMap* _tmp17_;
	gpointer _tmp18_;
	TrfPersonaStore* _tmp19_;
	TrfPersonaStore* _tmp20_;
	TrfPersonaStore* _tmp21_;
	GError* e;
	GError* _tmp22_;
	const gchar* _tmp23_;
	GError * _inner_error_;
};

struct _AddPersonaTestsAddPersonaData {
	int _state_;
	GObject* _source_object_;
	GAsyncResult* _res_;
	GSimpleAsyncResult* _async_result;
	AddPersonaTests* self;
	GHashTable* details;
	GHashFunc _tmp0_;
	GEqualFunc _tmp1_;
	GHashTable* _tmp2_;
	GValue* v1;
	GValue _tmp3_;
	GValue _tmp4_;
	GValue* _tmp5_;
	GValue* _tmp6_;
	GValue* _tmp7_;
	const gchar* _tmp8_;
	const gchar* _tmp9_;
	gchar* _tmp10_;
	GValue* _tmp11_;
	GValue* v2;
	GValue _tmp12_;
	GValue _tmp13_;
	GValue* _tmp14_;
	GValue* _tmp15_;
	GValue* _tmp16_;
	const gchar* _tmp17_;
	const gchar* _tmp18_;
	gchar* _tmp19_;
	GValue* _tmp20_;
	GValue* v3;
	GValue _tmp21_;
	GValue _tmp22_;
	GValue* _tmp23_;
	GValue* _tmp24_;
	GValue* _tmp25_;
	const gchar* _tmp26_;
	gchar* _tmp27_;
	GValue* _tmp28_;
	GValue* v4;
	GValue _tmp29_;
	GValue _tmp30_;
	GValue* _tmp31_;
	GValue* _tmp32_;
	FolksStructuredName* sname;
	const gchar* _tmp33_;
	const gchar* _tmp34_;
	FolksStructuredName* _tmp35_;
	GValue* _tmp36_;
	const gchar* _tmp37_;
	gchar* _tmp38_;
	GValue* _tmp39_;
	GValue* v5;
	GValue _tmp40_;
	GValue _tmp41_;
	GValue* _tmp42_;
	GValue* _tmp43_;
	GValue* _tmp44_;
	GLoadableIcon* _tmp45_;
	const gchar* _tmp46_;
	gchar* _tmp47_;
	GValue* _tmp48_;
	GValue* v6;
	GValue _tmp49_;
	GValue _tmp50_;
	GValue* _tmp51_;
	GValue* _tmp52_;
	GTimeVal t;
	const gchar* _tmp53_;
	GDateTime* dobj;
	GTimeVal _tmp54_;
	GDateTime* _tmp55_;
	GValue* _tmp56_;
	const gchar* _tmp57_;
	gchar* _tmp58_;
	GValue* _tmp59_;
	GValue* v7;
	GValue _tmp60_;
	GValue _tmp61_;
	GValue* _tmp62_;
	GValue* _tmp63_;
	GValue* _tmp64_;
	const gchar* _tmp65_;
	gchar* _tmp66_;
	GValue* _tmp67_;
	GValue* v8;
	GValue _tmp68_;
	GValue _tmp69_;
	GValue* _tmp70_;
	GValue* _tmp71_;
	GeeHashSet* emails;
	GeeHashSet* _tmp72_;
	FolksEmailFieldDetails* email_1;
	const gchar* _tmp73_;
	FolksEmailFieldDetails* _tmp74_;
	FolksEmailFieldDetails* email_2;
	const gchar* _tmp75_;
	FolksEmailFieldDetails* _tmp76_;
	GValue* _tmp77_;
	const gchar* _tmp78_;
	gchar* _tmp79_;
	GValue* _tmp80_;
	GValue* v9;
	GValue _tmp81_;
	GValue _tmp82_;
	GValue* _tmp83_;
	GValue* _tmp84_;
	GeeHashMultiMap* im_addrs;
	GeeHashMultiMap* _tmp85_;
	const gchar* _tmp86_;
	FolksImFieldDetails* _tmp87_;
	FolksImFieldDetails* _tmp88_;
	const gchar* _tmp89_;
	FolksImFieldDetails* _tmp90_;
	FolksImFieldDetails* _tmp91_;
	const gchar* _tmp92_;
	gchar* _tmp93_;
	GValue* _tmp94_;
	GValue* v10;
	GValue _tmp95_;
	GValue _tmp96_;
	GValue* _tmp97_;
	GValue* _tmp98_;
	GeeHashSet* notes;
	GeeHashSet* _tmp99_;
	FolksNoteFieldDetails* note_fd_1;
	const gchar* _tmp100_;
	FolksNoteFieldDetails* _tmp101_;
	GValue* _tmp102_;
	const gchar* _tmp103_;
	gchar* _tmp104_;
	GValue* _tmp105_;
	GValue* v11;
	GValue _tmp106_;
	GValue _tmp107_;
	GValue* _tmp108_;
	GValue* _tmp109_;
	GeeHashSet* phones;
	GeeHashSet* _tmp110_;
	FolksPhoneFieldDetails* phone_1;
	const gchar* _tmp111_;
	FolksPhoneFieldDetails* _tmp112_;
	FolksPhoneFieldDetails* phone_2;
	const gchar* _tmp113_;
	FolksPhoneFieldDetails* _tmp114_;
	GValue* _tmp115_;
	const gchar* _tmp116_;
	gchar* _tmp117_;
	GValue* _tmp118_;
	GValue* v12;
	GValue _tmp119_;
	GValue _tmp120_;
	GValue* _tmp121_;
	GValue* _tmp122_;
	GeeHashSet* role_fds;
	GeeHashSet* _tmp123_;
	FolksRole* r1;
	const gchar* _tmp124_;
	const gchar* _tmp125_;
	FolksRole* _tmp126_;
	const gchar* _tmp127_;
	FolksRoleFieldDetails* role_fd1;
	FolksRoleFieldDetails* _tmp128_;
	GValue* _tmp129_;
	const gchar* _tmp130_;
	gchar* _tmp131_;
	GValue* _tmp132_;
	GValue* v13;
	GValue _tmp133_;
	GValue _tmp134_;
	GValue* _tmp135_;
	GValue* _tmp136_;
	GeeHashSet* postal_addresses;
	GeeHashSet* _tmp137_;
	FolksPostalAddress* postal_a;
	const gchar* _tmp138_;
	const gchar* _tmp139_;
	const gchar* _tmp140_;
	const gchar* _tmp141_;
	const gchar* _tmp142_;
	const gchar* _tmp143_;
	const gchar* _tmp144_;
	FolksPostalAddress* _tmp145_;
	FolksPostalAddressFieldDetails* postal_a_fd;
	FolksPostalAddressFieldDetails* _tmp146_;
	GValue* _tmp147_;
	const gchar* _tmp148_;
	gchar* _tmp149_;
	GValue* _tmp150_;
	GValue* v14;
	GValue _tmp151_;
	GValue _tmp152_;
	GValue* _tmp153_;
	GValue* _tmp154_;
	GeeHashSet* urls;
	GeeHashSet* _tmp155_;
	FolksUrlFieldDetails* url_1;
	const gchar* _tmp156_;
	FolksUrlFieldDetails* _tmp157_;
	FolksUrlFieldDetails* url_2;
	const gchar* _tmp158_;
	FolksUrlFieldDetails* _tmp159_;
	GValue* _tmp160_;
	const gchar* _tmp161_;
	gchar* _tmp162_;
	GValue* _tmp163_;
	FolksPersona* _tmp164_;
	FolksIndividualAggregator* _tmp165_;
	TrfPersonaStore* _tmp166_;
	FolksPersona* _tmp167_;
	TrfPersona* persona;
	FolksPersona* _tmp168_;
	TrfPersona* _tmp169_;
	const gchar* _tmp170_;
	const gchar* _tmp171_;
	gchar* _tmp172_;
	GError* e;
	GError* _tmp173_;
	const gchar* _tmp174_;
	GError * _inner_error_;
};


static gpointer add_persona_tests_parent_class = NULL;

GType add_persona_tests_get_type (void) G_GNUC_CONST;
#define ADD_PERSONA_TESTS_GET_PRIVATE(o) (G_TYPE_INSTANCE_GET_PRIVATE ((o), TYPE_ADD_PERSONA_TESTS, AddPersonaTestsPrivate))
enum  {
	ADD_PERSONA_TESTS_DUMMY_PROPERTY
};
AddPersonaTests* add_persona_tests_new (void);
AddPersonaTests* add_persona_tests_construct (GType object_type);
void add_persona_tests_test_add_persona (AddPersonaTests* self);
static void _add_persona_tests_test_add_persona_folks_test_case_test_method (gpointer self);
static void _g_free0_ (gpointer var);
static void _add_persona_tests_test_add_persona_async (AddPersonaTests* self, GAsyncReadyCallback _callback_, gpointer _user_data_);
static void _add_persona_tests_test_add_persona_finish (AddPersonaTests* self, GAsyncResult* _res_);
static void _add_persona_tests_test_add_persona_async_data_free (gpointer _data);
static gboolean _add_persona_tests_test_add_persona_async_co (AddPersonaTestsTestAddPersonaAsyncData* _data_);
static void _add_persona_tests_test_add_persona_async_ready (GObject* source_object, GAsyncResult* _res_, gpointer _user_data_);
static void _add_persona_tests_individuals_changed_cb (AddPersonaTests* self, GeeMultiMap* changes);
static void __add_persona_tests_individuals_changed_cb_folks_individual_aggregator_individuals_changed_detailed (FolksIndividualAggregator* _sender, GeeMultiMap* changes, gpointer self);
static void _add_persona_tests_notify_pstore_cb (AddPersonaTests* self, GObject* _pstore, GParamSpec* ps);
static void __add_persona_tests_notify_pstore_cb_g_object_notify (GObject* _sender, GParamSpec* pspec, gpointer self);
static void _add_persona_tests_try_to_add (AddPersonaTests* self);
static void _add_persona_tests_add_persona_data_free (gpointer _data);
static void _add_persona_tests_add_persona (AddPersonaTests* self, GAsyncReadyCallback _callback_, gpointer _user_data_);
static void _add_persona_tests_add_persona_finish (AddPersonaTests* self, GAsyncResult* _res_);
static gboolean _add_persona_tests_add_persona_co (AddPersonaTestsAddPersonaData* _data_);
static void _vala_GValue_free (GValue* self);
static void __vala_GValue_free0_ (gpointer var);
static GValue* _g_value_dup (GValue* self);
static guint _folks_abstract_field_details_hash_static_gee_hash_data_func (gconstpointer v, gpointer self);
static gboolean _folks_abstract_field_details_equal_static_gee_equal_data_func (gconstpointer a, gconstpointer b, gpointer self);
static void _add_persona_tests_add_persona_ready (GObject* source_object, GAsyncResult* _res_, gpointer _user_data_);
static void _add_persona_tests_notify_persona_sname (AddPersonaTests* self, GObject* persona_p, GParamSpec* ps);
static void __add_persona_tests_notify_persona_sname_g_object_notify (GObject* _sender, GParamSpec* pspec, gpointer self);
static void _add_persona_tests_notify_cb (AddPersonaTests* self, GObject* individual_obj, GParamSpec* ps);
static void __add_persona_tests_notify_cb_g_object_notify (GObject* _sender, GParamSpec* pspec, gpointer self);
static void _add_persona_tests_check_properties (AddPersonaTests* self, FolksIndividual* i);
static void _add_persona_tests_check_sname (AddPersonaTests* self, FolksStructuredName* sname);
static void _add_persona_tests_exit_if_all_properties_found (AddPersonaTests* self);
static void ___lambda4_ (AddPersonaTests* self, GObject* obj, GAsyncResult* _result_);
static void ____lambda4__gasync_ready_callback (GObject* source_object, GAsyncResult* res, gpointer self);
static void add_persona_tests_finalize (GObject* obj);
gint _vala_main (gchar** args, int args_length1);


static void _add_persona_tests_test_add_persona_folks_test_case_test_method (gpointer self) {
#line 66 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
	add_persona_tests_test_add_persona ((AddPersonaTests*) self);
#line 412 "add-persona.c"
}


AddPersonaTests* add_persona_tests_construct (GType object_type) {
	AddPersonaTests * self = NULL;
#line 64 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
	self = (AddPersonaTests*) tracker_test_test_case_construct (object_type, "AddPersonaTests");
#line 66 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
	folks_test_case_add_test ((FolksTestCase*) self, "test adding personas to Tracker ", _add_persona_tests_test_add_persona_folks_test_case_test_method, g_object_ref (self), g_object_unref);
#line 62 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
	return self;
#line 424 "add-persona.c"
}


AddPersonaTests* add_persona_tests_new (void) {
#line 62 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
	return add_persona_tests_construct (TYPE_ADD_PERSONA_TESTS);
#line 431 "add-persona.c"
}


static void _g_free0_ (gpointer var) {
#line 101 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
	var = (g_free (var), NULL);
#line 438 "add-persona.c"
}


void add_persona_tests_test_add_persona (AddPersonaTests* self) {
	GMainLoop* _tmp0_ = NULL;
	gchar* _tmp1_ = NULL;
	gchar* _tmp2_ = NULL;
	gchar* _tmp3_ = NULL;
	gchar* _tmp4_ = NULL;
	gchar* _tmp5_ = NULL;
	gchar* _avatar_path = NULL;
	gchar* _tmp6_ = NULL;
	const gchar* _tmp7_ = NULL;
	GFile* _tmp8_ = NULL;
	GFile* _tmp9_ = NULL;
	GFileIcon* _tmp10_ = NULL;
	gchar* _tmp11_ = NULL;
	gchar* _tmp12_ = NULL;
	gchar* _tmp13_ = NULL;
	gchar* _tmp14_ = NULL;
	gchar* _tmp15_ = NULL;
	gchar* _tmp16_ = NULL;
	gchar* _tmp17_ = NULL;
	gchar* _tmp18_ = NULL;
	gchar* _tmp19_ = NULL;
	gchar* _tmp20_ = NULL;
	gchar* _tmp21_ = NULL;
	FolksPostalAddress* address = NULL;
	const gchar* _tmp22_ = NULL;
	const gchar* _tmp23_ = NULL;
	const gchar* _tmp24_ = NULL;
	const gchar* _tmp25_ = NULL;
	const gchar* _tmp26_ = NULL;
	const gchar* _tmp27_ = NULL;
	const gchar* _tmp28_ = NULL;
	FolksPostalAddress* _tmp29_ = NULL;
	FolksPostalAddress* _tmp30_ = NULL;
	FolksPostalAddressFieldDetails* _tmp31_ = NULL;
	GTimeVal t = {0};
	const gchar* _tmp32_ = NULL;
	GTimeVal _tmp33_ = {0};
	GDateTime* _tmp34_ = NULL;
	GHashFunc _tmp35_ = NULL;
	GEqualFunc _tmp36_ = NULL;
	GHashTable* _tmp37_ = NULL;
	GHashTable* _tmp38_ = NULL;
	gchar* _tmp39_ = NULL;
	GHashTable* _tmp40_ = NULL;
	gchar* _tmp41_ = NULL;
	GHashTable* _tmp42_ = NULL;
	gchar* _tmp43_ = NULL;
	GHashTable* _tmp44_ = NULL;
	gchar* _tmp45_ = NULL;
	GHashTable* _tmp46_ = NULL;
	gchar* _tmp47_ = NULL;
	GHashTable* _tmp48_ = NULL;
	gchar* _tmp49_ = NULL;
	GHashTable* _tmp50_ = NULL;
	gchar* _tmp51_ = NULL;
	GHashTable* _tmp52_ = NULL;
	gchar* _tmp53_ = NULL;
	GHashTable* _tmp54_ = NULL;
	gchar* _tmp55_ = NULL;
	GHashTable* _tmp56_ = NULL;
	gchar* _tmp57_ = NULL;
	GHashTable* _tmp58_ = NULL;
	gchar* _tmp59_ = NULL;
	GHashTable* _tmp60_ = NULL;
	gchar* _tmp61_ = NULL;
	GHashTable* _tmp62_ = NULL;
	gchar* _tmp63_ = NULL;
	GHashTable* _tmp64_ = NULL;
	gchar* _tmp65_ = NULL;
	GHashTable* _tmp66_ = NULL;
	gchar* _tmp67_ = NULL;
	GHashTable* _tmp68_ = NULL;
	gchar* _tmp69_ = NULL;
	GHashTable* _tmp70_ = NULL;
	gchar* _tmp71_ = NULL;
	GHashTable* _tmp72_ = NULL;
	gchar* _tmp73_ = NULL;
	GMainLoop* _tmp74_ = NULL;
	GHashTable* _tmp75_ = NULL;
	GList* _tmp76_ = NULL;
#line 69 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
	g_return_if_fail (self != NULL);
#line 71 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
	_tmp0_ = g_main_loop_new (NULL, FALSE);
#line 71 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
	_g_main_loop_unref0 (self->priv->_main_loop);
#line 71 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
	self->priv->_main_loop = _tmp0_;
#line 72 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
	_tmp1_ = g_strdup ("persona #1");
#line 72 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
	_g_free0 (self->priv->_persona_fullname);
#line 72 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
	self->priv->_persona_fullname = _tmp1_;
#line 73 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
	_tmp2_ = g_strdup ("nickname");
#line 73 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
	_g_free0 (self->priv->_persona_nickname);
#line 73 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
	self->priv->_persona_nickname = _tmp2_;
#line 74 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
	_tmp3_ = g_strdup ("family");
#line 74 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
	_g_free0 (self->priv->_family_name);
#line 74 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
	self->priv->_family_name = _tmp3_;
#line 75 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
	_tmp4_ = g_strdup ("given");
#line 75 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
	_g_free0 (self->priv->_given_name);
#line 75 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
	self->priv->_given_name = _tmp4_;
#line 76 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
	_tmp5_ = g_strdup ("");
#line 76 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
	_g_free0 (self->priv->_persona_iid);
#line 76 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
	self->priv->_persona_iid = _tmp5_;
#line 77 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
	_tmp6_ = folks_test_utils_get_source_test_data ("data/avatar-01.jpg");
#line 77 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
	_avatar_path = _tmp6_;
#line 79 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
	_tmp7_ = _avatar_path;
#line 79 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
	_tmp8_ = g_file_new_for_path (_tmp7_);
#line 79 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
	_tmp9_ = _tmp8_;
#line 79 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
	_tmp10_ = (GFileIcon*) g_file_icon_new (_tmp9_);
#line 79 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
	_g_object_unref0 (self->priv->_avatar);
#line 79 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
	self->priv->_avatar = (GLoadableIcon*) _tmp10_;
#line 79 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
	_g_object_unref0 (_tmp9_);
#line 80 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
	_tmp11_ = g_strdup ("2001-10-26T20:32:52Z");
#line 80 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
	_g_free0 (self->priv->_birthday);
#line 80 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
	self->priv->_birthday = _tmp11_;
#line 81 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
	_tmp12_ = g_strdup ("someone-1@example.org");
#line 81 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
	_g_free0 (self->priv->_email_1);
#line 81 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
	self->priv->_email_1 = _tmp12_;
#line 82 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
	_tmp13_ = g_strdup ("someone-2@example.org");
#line 82 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
	_g_free0 (self->priv->_email_2);
#line 82 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
	self->priv->_email_2 = _tmp13_;
#line 83 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
	_tmp14_ = g_strdup ("someone-1@jabber.example.org");
#line 83 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
	_g_free0 (self->priv->_im_addr_1);
#line 83 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
	self->priv->_im_addr_1 = _tmp14_;
#line 84 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
	_tmp15_ = g_strdup ("someone-2@jabber.example.org");
#line 84 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
	_g_free0 (self->priv->_im_addr_2);
#line 84 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
	self->priv->_im_addr_2 = _tmp15_;
#line 85 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
	_tmp16_ = g_strdup ("this is a note");
#line 85 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
	_g_free0 (self->priv->_note_1);
#line 85 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
	self->priv->_note_1 = _tmp16_;
#line 86 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
	_tmp17_ = g_strdup ("12345");
#line 86 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
	_g_free0 (self->priv->_phone_1);
#line 86 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
	self->priv->_phone_1 = _tmp17_;
#line 87 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
	_tmp18_ = g_strdup ("54321");
#line 87 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
	_g_free0 (self->priv->_phone_2);
#line 87 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
	self->priv->_phone_2 = _tmp18_;
#line 88 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
	_tmp19_ = g_strdup ("CFO");
#line 88 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
	_g_free0 (self->priv->_title_1);
#line 88 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
	self->priv->_title_1 = _tmp19_;
#line 89 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
	_tmp20_ = g_strdup ("Example Inc.");
#line 89 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
	_g_free0 (self->priv->_organisation_1);
#line 89 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
	self->priv->_organisation_1 = _tmp20_;
#line 90 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
	_tmp21_ = g_strdup ("Role");
#line 90 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
	_g_free0 (self->priv->_role_1);
#line 90 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
	self->priv->_role_1 = _tmp21_;
#line 92 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
	_tmp22_ = self->priv->_po_box;
#line 92 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
	_tmp23_ = self->priv->_extension;
#line 92 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
	_tmp24_ = self->priv->_street;
#line 92 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
	_tmp25_ = self->priv->_locality;
#line 92 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
	_tmp26_ = self->priv->_region;
#line 92 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
	_tmp27_ = self->priv->_postal_code;
#line 92 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
	_tmp28_ = self->priv->_country;
#line 92 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
	_tmp29_ = folks_postal_address_new (_tmp22_, _tmp23_, _tmp24_, _tmp25_, _tmp26_, _tmp27_, _tmp28_, NULL, NULL);
#line 92 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
	address = _tmp29_;
#line 95 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
	_tmp30_ = address;
#line 95 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
	_tmp31_ = folks_postal_address_field_details_new (_tmp30_, NULL);
#line 95 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
	_g_object_unref0 (self->priv->_postal_address_fd);
#line 95 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
	self->priv->_postal_address_fd = _tmp31_;
#line 97 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
	g_get_current_time (&t);
#line 98 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
	_tmp32_ = self->priv->_birthday;
#line 98 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
	g_time_val_from_iso8601 (_tmp32_, &t);
#line 99 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
	_tmp33_ = t;
#line 99 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
	_tmp34_ = g_date_time_new_from_timeval_utc (&_tmp33_);
#line 99 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
	_g_date_time_unref0 (self->priv->_bday);
#line 99 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
	self->priv->_bday = _tmp34_;
#line 101 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
	_tmp35_ = g_str_hash;
#line 101 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
	_tmp36_ = g_str_equal;
#line 101 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
	_tmp37_ = g_hash_table_new_full (_tmp35_, _tmp36_, _g_free0_, NULL);
#line 101 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
	_g_hash_table_unref0 (self->priv->_properties_found);
#line 101 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
	self->priv->_properties_found = _tmp37_;
#line 103 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
	_tmp38_ = self->priv->_properties_found;
#line 103 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
	_tmp39_ = g_strdup ("full_name");
#line 103 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
	g_hash_table_insert (_tmp38_, _tmp39_, (gpointer) ((gintptr) FALSE));
#line 104 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
	_tmp40_ = self->priv->_properties_found;
#line 104 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
	_tmp41_ = g_strdup ("nickname");
#line 104 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
	g_hash_table_insert (_tmp40_, _tmp41_, (gpointer) ((gintptr) FALSE));
#line 105 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
	_tmp42_ = self->priv->_properties_found;
#line 105 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
	_tmp43_ = g_strdup ("is_favourite");
#line 105 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
	g_hash_table_insert (_tmp42_, _tmp43_, (gpointer) ((gintptr) FALSE));
#line 106 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
	_tmp44_ = self->priv->_properties_found;
#line 106 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
	_tmp45_ = g_strdup ("structured_name");
#line 106 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
	g_hash_table_insert (_tmp44_, _tmp45_, (gpointer) ((gintptr) FALSE));
#line 107 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
	_tmp46_ = self->priv->_properties_found;
#line 107 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
	_tmp47_ = g_strdup ("avatar");
#line 107 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
	g_hash_table_insert (_tmp46_, _tmp47_, (gpointer) ((gintptr) FALSE));
#line 108 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
	_tmp48_ = self->priv->_properties_found;
#line 108 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
	_tmp49_ = g_strdup ("birthday");
#line 108 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
	g_hash_table_insert (_tmp48_, _tmp49_, (gpointer) ((gintptr) FALSE));
#line 109 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
	_tmp50_ = self->priv->_properties_found;
#line 109 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
	_tmp51_ = g_strdup ("gender");
#line 109 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
	g_hash_table_insert (_tmp50_, _tmp51_, (gpointer) ((gintptr) FALSE));
#line 110 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
	_tmp52_ = self->priv->_properties_found;
#line 110 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
	_tmp53_ = g_strdup ("email-1");
#line 110 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
	g_hash_table_insert (_tmp52_, _tmp53_, (gpointer) ((gintptr) FALSE));
#line 111 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
	_tmp54_ = self->priv->_properties_found;
#line 111 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
	_tmp55_ = g_strdup ("email-2");
#line 111 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
	g_hash_table_insert (_tmp54_, _tmp55_, (gpointer) ((gintptr) FALSE));
#line 112 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
	_tmp56_ = self->priv->_properties_found;
#line 112 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
	_tmp57_ = g_strdup ("im-addr-1");
#line 112 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
	g_hash_table_insert (_tmp56_, _tmp57_, (gpointer) ((gintptr) FALSE));
#line 113 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
	_tmp58_ = self->priv->_properties_found;
#line 113 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
	_tmp59_ = g_strdup ("im-addr-2");
#line 113 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
	g_hash_table_insert (_tmp58_, _tmp59_, (gpointer) ((gintptr) FALSE));
#line 114 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
	_tmp60_ = self->priv->_properties_found;
#line 114 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
	_tmp61_ = g_strdup ("note-1");
#line 114 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
	g_hash_table_insert (_tmp60_, _tmp61_, (gpointer) ((gintptr) FALSE));
#line 115 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
	_tmp62_ = self->priv->_properties_found;
#line 115 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
	_tmp63_ = g_strdup ("phone-1");
#line 115 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
	g_hash_table_insert (_tmp62_, _tmp63_, (gpointer) ((gintptr) FALSE));
#line 116 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
	_tmp64_ = self->priv->_properties_found;
#line 116 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
	_tmp65_ = g_strdup ("phone-2");
#line 116 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
	g_hash_table_insert (_tmp64_, _tmp65_, (gpointer) ((gintptr) FALSE));
#line 117 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
	_tmp66_ = self->priv->_properties_found;
#line 117 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
	_tmp67_ = g_strdup ("role-1");
#line 117 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
	g_hash_table_insert (_tmp66_, _tmp67_, (gpointer) ((gintptr) FALSE));
#line 118 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
	_tmp68_ = self->priv->_properties_found;
#line 118 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
	_tmp69_ = g_strdup ("postal-address-1");
#line 118 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
	g_hash_table_insert (_tmp68_, _tmp69_, (gpointer) ((gintptr) FALSE));
#line 119 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
	_tmp70_ = self->priv->_properties_found;
#line 119 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
	_tmp71_ = g_strdup ("url-1");
#line 119 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
	g_hash_table_insert (_tmp70_, _tmp71_, (gpointer) ((gintptr) FALSE));
#line 120 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
	_tmp72_ = self->priv->_properties_found;
#line 120 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
	_tmp73_ = g_strdup ("url-2");
#line 120 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
	g_hash_table_insert (_tmp72_, _tmp73_, (gpointer) ((gintptr) FALSE));
#line 122 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
	_add_persona_tests_test_add_persona_async (self, NULL, NULL);
#line 124 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
	_tmp74_ = self->priv->_main_loop;
#line 124 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
	folks_test_utils_loop_run_with_timeout (_tmp74_, 5);
#line 126 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
	_tmp75_ = self->priv->_properties_found;
#line 126 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
	_tmp76_ = g_hash_table_get_values (_tmp75_);
#line 813 "add-persona.c"
	{
		GList* k_collection = NULL;
		GList* k_it = NULL;
#line 126 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
		k_collection = _tmp76_;
#line 126 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
		for (k_it = k_collection; k_it != NULL; k_it = k_it->next) {
#line 821 "add-persona.c"
			gboolean k = FALSE;
#line 126 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
			k = (gboolean) ((gintptr) k_it->data);
#line 825 "add-persona.c"
			{
				gboolean _tmp77_ = FALSE;
#line 128 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
				_tmp77_ = k;
#line 128 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
				_vala_assert (_tmp77_, "k");
#line 832 "add-persona.c"
			}
		}
#line 126 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
		_g_list_free0 (k_collection);
#line 837 "add-persona.c"
	}
#line 69 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
	_g_object_unref0 (address);
#line 69 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
	_g_free0 (_avatar_path);
#line 843 "add-persona.c"
}


static void _add_persona_tests_test_add_persona_async_data_free (gpointer _data) {
	AddPersonaTestsTestAddPersonaAsyncData* _data_;
	_data_ = _data;
#line 26 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
	_g_object_unref0 (_data_->self);
#line 26 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
	g_slice_free (AddPersonaTestsTestAddPersonaAsyncData, _data_);
#line 854 "add-persona.c"
}


static gpointer _g_object_ref0 (gpointer self) {
#line 26 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
	return self ? g_object_ref (self) : NULL;
#line 861 "add-persona.c"
}


static void _add_persona_tests_test_add_persona_async (AddPersonaTests* self, GAsyncReadyCallback _callback_, gpointer _user_data_) {
	AddPersonaTestsTestAddPersonaAsyncData* _data_;
	AddPersonaTests* _tmp0_ = NULL;
#line 26 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
	_data_ = g_slice_new0 (AddPersonaTestsTestAddPersonaAsyncData);
#line 26 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
	_data_->_async_result = g_simple_async_result_new (G_OBJECT (self), _callback_, _user_data_, _add_persona_tests_test_add_persona_async);
#line 26 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
	g_simple_async_result_set_op_res_gpointer (_data_->_async_result, _data_, _add_persona_tests_test_add_persona_async_data_free);
#line 26 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
	_tmp0_ = _g_object_ref0 (self);
#line 26 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
	_data_->self = _tmp0_;
#line 26 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
	_add_persona_tests_test_add_persona_async_co (_data_);
#line 880 "add-persona.c"
}


static void _add_persona_tests_test_add_persona_finish (AddPersonaTests* self, GAsyncResult* _res_) {
	AddPersonaTestsTestAddPersonaAsyncData* _data_;
#line 26 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
	_data_ = g_simple_async_result_get_op_res_gpointer (G_SIMPLE_ASYNC_RESULT (_res_));
#line 888 "add-persona.c"
}


static void _add_persona_tests_test_add_persona_async_ready (GObject* source_object, GAsyncResult* _res_, gpointer _user_data_) {
	AddPersonaTestsTestAddPersonaAsyncData* _data_;
#line 135 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
	_data_ = _user_data_;
#line 135 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
	_data_->_source_object_ = source_object;
#line 135 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
	_data_->_res_ = _res_;
#line 135 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
	_add_persona_tests_test_add_persona_async_co (_data_);
#line 902 "add-persona.c"
}


static void __add_persona_tests_individuals_changed_cb_folks_individual_aggregator_individuals_changed_detailed (FolksIndividualAggregator* _sender, GeeMultiMap* changes, gpointer self) {
#line 137 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
	_add_persona_tests_individuals_changed_cb ((AddPersonaTests*) self, changes);
#line 909 "add-persona.c"
}


static void __add_persona_tests_notify_pstore_cb_g_object_notify (GObject* _sender, GParamSpec* pspec, gpointer self) {
#line 152 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
	_add_persona_tests_notify_pstore_cb ((AddPersonaTests*) self, _sender, pspec);
#line 916 "add-persona.c"
}


static gboolean _add_persona_tests_test_add_persona_async_co (AddPersonaTestsTestAddPersonaAsyncData* _data_) {
#line 132 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
	switch (_data_->_state_) {
#line 132 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
		case 0:
#line 925 "add-persona.c"
		goto _state_0;
#line 132 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
		case 1:
#line 929 "add-persona.c"
		goto _state_1;
#line 132 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
		case 2:
#line 933 "add-persona.c"
		goto _state_2;
		default:
#line 132 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
		g_assert_not_reached ();
#line 938 "add-persona.c"
	}
	_state_0:
#line 134 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
	_data_->_tmp0_ = NULL;
#line 134 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
	_data_->_tmp0_ = folks_backend_store_dup ();
#line 134 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
	_data_->store = _data_->_tmp0_;
#line 135 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
	_data_->_state_ = 1;
#line 135 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
	folks_backend_store_prepare (_data_->store, _add_persona_tests_test_add_persona_async_ready, _data_);
#line 135 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
	return FALSE;
#line 953 "add-persona.c"
	_state_1:
#line 135 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
	folks_backend_store_prepare_finish (_data_->store, _data_->_res_);
#line 136 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
	_data_->_tmp1_ = NULL;
#line 136 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
	_data_->_tmp1_ = folks_individual_aggregator_dup ();
#line 136 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
	_g_object_unref0 (_data_->self->priv->_aggregator);
#line 136 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
	_data_->self->priv->_aggregator = _data_->_tmp1_;
#line 137 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
	_data_->_tmp2_ = NULL;
#line 137 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
	_data_->_tmp2_ = _data_->self->priv->_aggregator;
#line 137 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
	g_signal_connect_object (_data_->_tmp2_, "individuals-changed-detailed", (GCallback) __add_persona_tests_individuals_changed_cb_folks_individual_aggregator_individuals_changed_detailed, _data_->self, 0);
#line 971 "add-persona.c"
	{
#line 141 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
		_data_->_tmp3_ = NULL;
#line 141 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
		_data_->_tmp3_ = _data_->self->priv->_aggregator;
#line 141 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
		_data_->_state_ = 2;
#line 141 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
		folks_individual_aggregator_prepare (_data_->_tmp3_, _add_persona_tests_test_add_persona_async_ready, _data_);
#line 141 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
		return FALSE;
#line 983 "add-persona.c"
		_state_2:
#line 141 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
		folks_individual_aggregator_prepare_finish (_data_->_tmp3_, _data_->_res_, &_data_->_inner_error_);
#line 141 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
		if (G_UNLIKELY (_data_->_inner_error_ != NULL)) {
#line 989 "add-persona.c"
			goto __catch0_g_error;
		}
#line 143 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
		_g_object_unref0 (_data_->self->priv->_pstore);
#line 143 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
		_data_->self->priv->_pstore = NULL;
#line 996 "add-persona.c"
		{
#line 144 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
			_data_->_tmp4_ = NULL;
#line 144 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
			_data_->_tmp4_ = folks_backend_store_get_enabled_backends (_data_->store);
#line 144 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
			_data_->_tmp5_ = NULL;
#line 144 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
			_data_->_tmp5_ = _data_->_tmp4_;
#line 144 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
			_data_->_tmp6_ = NULL;
#line 144 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
			_data_->_tmp6_ = gee_map_get_values (_data_->_tmp5_);
#line 144 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
			_data_->_tmp7_ = NULL;
#line 144 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
			_data_->_tmp7_ = _data_->_tmp6_;
#line 144 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
			_data_->_tmp8_ = NULL;
#line 144 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
			_data_->_tmp8_ = _data_->_tmp7_;
#line 144 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
			_data_->_tmp9_ = NULL;
#line 144 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
			_data_->_tmp9_ = gee_iterable_iterator ((GeeIterable*) _data_->_tmp8_);
#line 144 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
			_data_->_tmp10_ = NULL;
#line 144 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
			_data_->_tmp10_ = _data_->_tmp9_;
#line 144 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
			_g_object_unref0 (_data_->_tmp8_);
#line 144 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
			_data_->_backend_it = _data_->_tmp10_;
#line 144 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
			while (TRUE) {
#line 144 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
				_data_->_tmp11_ = NULL;
#line 144 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
				_data_->_tmp11_ = _data_->_backend_it;
#line 144 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
				_data_->_tmp12_ = FALSE;
#line 144 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
				_data_->_tmp12_ = gee_iterator_next (_data_->_tmp11_);
#line 144 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
				if (!_data_->_tmp12_) {
#line 144 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
					break;
#line 1044 "add-persona.c"
				}
#line 144 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
				_data_->_tmp13_ = NULL;
#line 144 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
				_data_->_tmp13_ = _data_->_backend_it;
#line 144 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
				_data_->_tmp14_ = NULL;
#line 144 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
				_data_->_tmp14_ = gee_iterator_get (_data_->_tmp13_);
#line 144 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
				_data_->backend = (FolksBackend*) _data_->_tmp14_;
#line 146 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
				_data_->_tmp15_ = NULL;
#line 146 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
				_data_->_tmp15_ = _data_->backend;
#line 146 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
				_data_->_tmp16_ = NULL;
#line 146 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
				_data_->_tmp16_ = folks_backend_get_persona_stores (_data_->_tmp15_);
#line 146 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
				_data_->_tmp17_ = NULL;
#line 146 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
				_data_->_tmp17_ = _data_->_tmp16_;
#line 146 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
				_data_->_tmp18_ = NULL;
#line 146 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
				_data_->_tmp18_ = gee_map_get (_data_->_tmp17_, "tracker");
#line 146 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
				_g_object_unref0 (_data_->self->priv->_pstore);
#line 146 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
				_data_->self->priv->_pstore = G_TYPE_CHECK_INSTANCE_CAST ((FolksPersonaStore*) _data_->_tmp18_, TRF_TYPE_PERSONA_STORE, TrfPersonaStore);
#line 148 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
				_data_->_tmp19_ = NULL;
#line 148 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
				_data_->_tmp19_ = _data_->self->priv->_pstore;
#line 148 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
				if (_data_->_tmp19_ != NULL) {
#line 149 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
					_g_object_unref0 (_data_->backend);
#line 149 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
					break;
#line 1086 "add-persona.c"
				}
#line 144 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
				_g_object_unref0 (_data_->backend);
#line 1090 "add-persona.c"
			}
#line 144 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
			_g_object_unref0 (_data_->_backend_it);
#line 1094 "add-persona.c"
		}
#line 151 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
		_data_->_tmp20_ = NULL;
#line 151 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
		_data_->_tmp20_ = _data_->self->priv->_pstore;
#line 151 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
		_vala_assert (_data_->_tmp20_ != NULL, "this._pstore != null");
#line 152 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
		_data_->_tmp21_ = NULL;
#line 152 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
		_data_->_tmp21_ = _data_->self->priv->_pstore;
#line 152 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
		g_signal_connect_object ((GObject*) _data_->_tmp21_, "notify::is-prepared", (GCallback) __add_persona_tests_notify_pstore_cb_g_object_notify, _data_->self, 0);
#line 153 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
		_add_persona_tests_try_to_add (_data_->self);
#line 1110 "add-persona.c"
	}
	goto __finally0;
	__catch0_g_error:
	{
#line 139 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
		_data_->e = _data_->_inner_error_;
#line 139 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
		_data_->_inner_error_ = NULL;
#line 157 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
		_data_->_tmp22_ = NULL;
#line 157 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
		_data_->_tmp22_ = _data_->e;
#line 157 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
		_data_->_tmp23_ = NULL;
#line 157 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
		_data_->_tmp23_ = _data_->_tmp22_->message;
#line 157 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
		g_warning ("add-persona.vala:157: Error when calling prepare: %s\n", _data_->_tmp23_);
#line 139 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
		_g_error_free0 (_data_->e);
#line 1131 "add-persona.c"
	}
	__finally0:
#line 139 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
	if (G_UNLIKELY (_data_->_inner_error_ != NULL)) {
#line 139 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
		_g_object_unref0 (_data_->store);
#line 139 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _data_->_inner_error_->message, g_quark_to_string (_data_->_inner_error_->domain), _data_->_inner_error_->code);
#line 139 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
		g_clear_error (&_data_->_inner_error_);
#line 139 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
		return FALSE;
#line 1144 "add-persona.c"
	}
#line 132 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
	_g_object_unref0 (_data_->store);
#line 132 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
	if (_data_->_state_ == 0) {
#line 132 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
		g_simple_async_result_complete_in_idle (_data_->_async_result);
#line 1152 "add-persona.c"
	} else {
#line 132 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
		g_simple_async_result_complete (_data_->_async_result);
#line 1156 "add-persona.c"
	}
#line 132 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
	g_object_unref (_data_->_async_result);
#line 132 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
	return FALSE;
#line 1162 "add-persona.c"
}


static void _add_persona_tests_add_persona_data_free (gpointer _data) {
	AddPersonaTestsAddPersonaData* _data_;
	_data_ = _data;
#line 26 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
	_g_object_unref0 (_data_->self);
#line 26 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
	g_slice_free (AddPersonaTestsAddPersonaData, _data_);
#line 1173 "add-persona.c"
}


static void _add_persona_tests_add_persona (AddPersonaTests* self, GAsyncReadyCallback _callback_, gpointer _user_data_) {
	AddPersonaTestsAddPersonaData* _data_;
	AddPersonaTests* _tmp0_ = NULL;
#line 26 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
	_data_ = g_slice_new0 (AddPersonaTestsAddPersonaData);
#line 26 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
	_data_->_async_result = g_simple_async_result_new (G_OBJECT (self), _callback_, _user_data_, _add_persona_tests_add_persona);
#line 26 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
	g_simple_async_result_set_op_res_gpointer (_data_->_async_result, _data_, _add_persona_tests_add_persona_data_free);
#line 26 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
	_tmp0_ = _g_object_ref0 (self);
#line 26 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
	_data_->self = _tmp0_;
#line 26 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
	_add_persona_tests_add_persona_co (_data_);
#line 1192 "add-persona.c"
}


static void _add_persona_tests_add_persona_finish (AddPersonaTests* self, GAsyncResult* _res_) {
	AddPersonaTestsAddPersonaData* _data_;
#line 26 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
	_data_ = g_simple_async_result_get_op_res_gpointer (G_SIMPLE_ASYNC_RESULT (_res_));
#line 1200 "add-persona.c"
}


static void _vala_GValue_free (GValue* self) {
#line 163 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
	g_value_unset (self);
#line 163 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
	g_free (self);
#line 1209 "add-persona.c"
}


static void __vala_GValue_free0_ (gpointer var) {
#line 163 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
	(var == NULL) ? NULL : (var = (_vala_GValue_free (var), NULL));
#line 1216 "add-persona.c"
}


static GValue* _g_value_dup (GValue* self) {
#line 166 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
	return g_boxed_copy (G_TYPE_VALUE, self);
#line 1223 "add-persona.c"
}


static gpointer __g_value_dup0 (gpointer self) {
#line 166 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
	return self ? _g_value_dup (self) : NULL;
#line 1230 "add-persona.c"
}


static guint _folks_abstract_field_details_hash_static_gee_hash_data_func (gconstpointer v, gpointer self) {
	guint result;
	result = folks_abstract_field_details_hash_static ((FolksAbstractFieldDetails*) v);
#line 209 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
	return result;
#line 1239 "add-persona.c"
}


static gboolean _folks_abstract_field_details_equal_static_gee_equal_data_func (gconstpointer a, gconstpointer b, gpointer self) {
	gboolean result;
	result = folks_abstract_field_details_equal_static ((FolksAbstractFieldDetails*) a, (FolksAbstractFieldDetails*) b);
#line 209 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
	return result;
#line 1248 "add-persona.c"
}


static void _add_persona_tests_add_persona_ready (GObject* source_object, GAsyncResult* _res_, gpointer _user_data_) {
	AddPersonaTestsAddPersonaData* _data_;
#line 297 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
	_data_ = _user_data_;
#line 297 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
	_data_->_source_object_ = source_object;
#line 297 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
	_data_->_res_ = _res_;
#line 297 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
	_add_persona_tests_add_persona_co (_data_);
#line 1262 "add-persona.c"
}


static gboolean _add_persona_tests_add_persona_co (AddPersonaTestsAddPersonaData* _data_) {
#line 161 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
	switch (_data_->_state_) {
#line 161 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
		case 0:
#line 1271 "add-persona.c"
		goto _state_0;
#line 161 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
		case 1:
#line 1275 "add-persona.c"
		goto _state_1;
		default:
#line 161 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
		g_assert_not_reached ();
#line 1280 "add-persona.c"
	}
	_state_0:
#line 163 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
	_data_->_tmp0_ = NULL;
#line 163 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
	_data_->_tmp0_ = g_str_hash;
#line 163 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
	_data_->_tmp1_ = NULL;
#line 163 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
	_data_->_tmp1_ = g_str_equal;
#line 163 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
	_data_->_tmp2_ = NULL;
#line 163 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
	_data_->_tmp2_ = g_hash_table_new_full (_data_->_tmp0_, _data_->_tmp1_, _g_free0_, __vala_GValue_free0_);
#line 163 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
	_data_->details = _data_->_tmp2_;
#line 166 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
	memset (&_data_->_tmp3_, 0, sizeof (GValue));
#line 166 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
	g_value_init (&_data_->_tmp3_, G_TYPE_STRING);
#line 166 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
	memset (&_data_->_tmp4_, 0, sizeof (GValue));
#line 166 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
	_data_->_tmp4_ = _data_->_tmp3_;
#line 166 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
	_data_->_tmp5_ = NULL;
#line 166 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
	_data_->_tmp5_ = __g_value_dup0 (&_data_->_tmp4_);
#line 166 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
	_data_->_tmp6_ = NULL;
#line 166 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
	_data_->_tmp6_ = _data_->_tmp5_;
#line 166 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
	G_IS_VALUE (&_data_->_tmp4_) ? (g_value_unset (&_data_->_tmp4_), NULL) : NULL;
#line 166 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
	_data_->v1 = _data_->_tmp6_;
#line 167 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
	_data_->_tmp7_ = NULL;
#line 167 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
	_data_->_tmp7_ = _data_->v1;
#line 167 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
	_data_->_tmp8_ = NULL;
#line 167 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
	_data_->_tmp8_ = _data_->self->priv->_persona_fullname;
#line 167 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
	g_value_set_string (_data_->_tmp7_, _data_->_tmp8_);
#line 168 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
	_data_->_tmp9_ = NULL;
#line 168 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
	_data_->_tmp9_ = folks_persona_store_detail_key (FOLKS_PERSONA_DETAIL_FULL_NAME);
#line 168 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
	_data_->_tmp10_ = NULL;
#line 168 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
	_data_->_tmp10_ = g_strdup (_data_->_tmp9_);
#line 168 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
	_data_->_tmp11_ = NULL;
#line 168 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
	_data_->_tmp11_ = _data_->v1;
#line 168 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
	_data_->v1 = NULL;
#line 168 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
	g_hash_table_insert (_data_->details, _data_->_tmp10_, _data_->_tmp11_);
#line 171 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
	memset (&_data_->_tmp12_, 0, sizeof (GValue));
#line 171 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
	g_value_init (&_data_->_tmp12_, G_TYPE_STRING);
#line 171 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
	memset (&_data_->_tmp13_, 0, sizeof (GValue));
#line 171 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
	_data_->_tmp13_ = _data_->_tmp12_;
#line 171 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
	_data_->_tmp14_ = NULL;
#line 171 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
	_data_->_tmp14_ = __g_value_dup0 (&_data_->_tmp13_);
#line 171 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
	_data_->_tmp15_ = NULL;
#line 171 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
	_data_->_tmp15_ = _data_->_tmp14_;
#line 171 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
	G_IS_VALUE (&_data_->_tmp13_) ? (g_value_unset (&_data_->_tmp13_), NULL) : NULL;
#line 171 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
	_data_->v2 = _data_->_tmp15_;
#line 172 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
	_data_->_tmp16_ = NULL;
#line 172 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
	_data_->_tmp16_ = _data_->v2;
#line 172 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
	_data_->_tmp17_ = NULL;
#line 172 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
	_data_->_tmp17_ = _data_->self->priv->_persona_nickname;
#line 172 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
	g_value_set_string (_data_->_tmp16_, _data_->_tmp17_);
#line 173 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
	_data_->_tmp18_ = NULL;
#line 173 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
	_data_->_tmp18_ = folks_persona_store_detail_key (FOLKS_PERSONA_DETAIL_NICKNAME);
#line 173 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
	_data_->_tmp19_ = NULL;
#line 173 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
	_data_->_tmp19_ = g_strdup (_data_->_tmp18_);
#line 173 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
	_data_->_tmp20_ = NULL;
#line 173 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
	_data_->_tmp20_ = _data_->v2;
#line 173 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
	_data_->v2 = NULL;
#line 173 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
	g_hash_table_insert (_data_->details, _data_->_tmp19_, _data_->_tmp20_);
#line 176 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
	memset (&_data_->_tmp21_, 0, sizeof (GValue));
#line 176 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
	g_value_init (&_data_->_tmp21_, G_TYPE_BOOLEAN);
#line 176 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
	memset (&_data_->_tmp22_, 0, sizeof (GValue));
#line 176 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
	_data_->_tmp22_ = _data_->_tmp21_;
#line 176 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
	_data_->_tmp23_ = NULL;
#line 176 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
	_data_->_tmp23_ = __g_value_dup0 (&_data_->_tmp22_);
#line 176 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
	_data_->_tmp24_ = NULL;
#line 176 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
	_data_->_tmp24_ = _data_->_tmp23_;
#line 176 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
	G_IS_VALUE (&_data_->_tmp22_) ? (g_value_unset (&_data_->_tmp22_), NULL) : NULL;
#line 176 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
	_data_->v3 = _data_->_tmp24_;
#line 177 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
	_data_->_tmp25_ = NULL;
#line 177 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
	_data_->_tmp25_ = _data_->v3;
#line 177 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
	g_value_set_boolean (_data_->_tmp25_, TRUE);
#line 178 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
	_data_->_tmp26_ = NULL;
#line 178 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
	_data_->_tmp26_ = folks_persona_store_detail_key (FOLKS_PERSONA_DETAIL_IS_FAVOURITE);
#line 178 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
	_data_->_tmp27_ = NULL;
#line 178 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
	_data_->_tmp27_ = g_strdup (_data_->_tmp26_);
#line 178 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
	_data_->_tmp28_ = NULL;
#line 178 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
	_data_->_tmp28_ = _data_->v3;
#line 178 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
	_data_->v3 = NULL;
#line 178 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
	g_hash_table_insert (_data_->details, _data_->_tmp27_, _data_->_tmp28_);
#line 182 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
	memset (&_data_->_tmp29_, 0, sizeof (GValue));
#line 182 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
	g_value_init (&_data_->_tmp29_, FOLKS_TYPE_STRUCTURED_NAME);
#line 182 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
	memset (&_data_->_tmp30_, 0, sizeof (GValue));
#line 182 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
	_data_->_tmp30_ = _data_->_tmp29_;
#line 182 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
	_data_->_tmp31_ = NULL;
#line 182 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
	_data_->_tmp31_ = __g_value_dup0 (&_data_->_tmp30_);
#line 182 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
	_data_->_tmp32_ = NULL;
#line 182 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
	_data_->_tmp32_ = _data_->_tmp31_;
#line 182 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
	G_IS_VALUE (&_data_->_tmp30_) ? (g_value_unset (&_data_->_tmp30_), NULL) : NULL;
#line 182 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
	_data_->v4 = _data_->_tmp32_;
#line 183 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
	_data_->_tmp33_ = NULL;
#line 183 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
	_data_->_tmp33_ = _data_->self->priv->_family_name;
#line 183 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
	_data_->_tmp34_ = NULL;
#line 183 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
	_data_->_tmp34_ = _data_->self->priv->_given_name;
#line 183 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
	_data_->_tmp35_ = NULL;
#line 183 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
	_data_->_tmp35_ = folks_structured_name_new (_data_->_tmp33_, _data_->_tmp34_, NULL, NULL, NULL);
#line 183 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
	_data_->sname = _data_->_tmp35_;
#line 185 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
	_data_->_tmp36_ = NULL;
#line 185 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
	_data_->_tmp36_ = _data_->v4;
#line 185 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
	g_value_set_object (_data_->_tmp36_, (GObject*) _data_->sname);
#line 186 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
	_data_->_tmp37_ = NULL;
#line 186 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
	_data_->_tmp37_ = folks_persona_store_detail_key (FOLKS_PERSONA_DETAIL_STRUCTURED_NAME);
#line 186 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
	_data_->_tmp38_ = NULL;
#line 186 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
	_data_->_tmp38_ = g_strdup (_data_->_tmp37_);
#line 186 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
	_data_->_tmp39_ = NULL;
#line 186 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
	_data_->_tmp39_ = _data_->v4;
#line 186 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
	_data_->v4 = NULL;
#line 186 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
	g_hash_table_insert (_data_->details, _data_->_tmp38_, _data_->_tmp39_);
#line 190 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
	memset (&_data_->_tmp40_, 0, sizeof (GValue));
#line 190 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
	g_value_init (&_data_->_tmp40_, g_loadable_icon_get_type ());
#line 190 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
	memset (&_data_->_tmp41_, 0, sizeof (GValue));
#line 190 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
	_data_->_tmp41_ = _data_->_tmp40_;
#line 190 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
	_data_->_tmp42_ = NULL;
#line 190 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
	_data_->_tmp42_ = __g_value_dup0 (&_data_->_tmp41_);
#line 190 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
	_data_->_tmp43_ = NULL;
#line 190 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
	_data_->_tmp43_ = _data_->_tmp42_;
#line 190 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
	G_IS_VALUE (&_data_->_tmp41_) ? (g_value_unset (&_data_->_tmp41_), NULL) : NULL;
#line 190 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
	_data_->v5 = _data_->_tmp43_;
#line 191 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
	_data_->_tmp44_ = NULL;
#line 191 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
	_data_->_tmp44_ = _data_->v5;
#line 191 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
	_data_->_tmp45_ = NULL;
#line 191 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
	_data_->_tmp45_ = _data_->self->priv->_avatar;
#line 191 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
	g_value_set_object (_data_->_tmp44_, (GObject*) _data_->_tmp45_);
#line 192 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
	_data_->_tmp46_ = NULL;
#line 192 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
	_data_->_tmp46_ = folks_persona_store_detail_key (FOLKS_PERSONA_DETAIL_AVATAR);
#line 192 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
	_data_->_tmp47_ = NULL;
#line 192 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
	_data_->_tmp47_ = g_strdup (_data_->_tmp46_);
#line 192 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
	_data_->_tmp48_ = NULL;
#line 192 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
	_data_->_tmp48_ = _data_->v5;
#line 192 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
	_data_->v5 = NULL;
#line 192 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
	g_hash_table_insert (_data_->details, _data_->_tmp47_, _data_->_tmp48_);
#line 195 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
	memset (&_data_->_tmp49_, 0, sizeof (GValue));
#line 195 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
	g_value_init (&_data_->_tmp49_, G_TYPE_DATE_TIME);
#line 195 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
	memset (&_data_->_tmp50_, 0, sizeof (GValue));
#line 195 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
	_data_->_tmp50_ = _data_->_tmp49_;
#line 195 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
	_data_->_tmp51_ = NULL;
#line 195 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
	_data_->_tmp51_ = __g_value_dup0 (&_data_->_tmp50_);
#line 195 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
	_data_->_tmp52_ = NULL;
#line 195 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
	_data_->_tmp52_ = _data_->_tmp51_;
#line 195 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
	G_IS_VALUE (&_data_->_tmp50_) ? (g_value_unset (&_data_->_tmp50_), NULL) : NULL;
#line 195 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
	_data_->v6 = _data_->_tmp52_;
#line 196 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
	g_get_current_time (&_data_->t);
#line 197 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
	_data_->_tmp53_ = NULL;
#line 197 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
	_data_->_tmp53_ = _data_->self->priv->_birthday;
#line 197 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
	g_time_val_from_iso8601 (_data_->_tmp53_, &_data_->t);
#line 198 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
	memset (&_data_->_tmp54_, 0, sizeof (GTimeVal));
#line 198 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
	_data_->_tmp54_ = _data_->t;
#line 198 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
	_data_->_tmp55_ = NULL;
#line 198 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
	_data_->_tmp55_ = g_date_time_new_from_timeval_utc (&_data_->_tmp54_);
#line 198 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
	_data_->dobj = _data_->_tmp55_;
#line 199 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
	_data_->_tmp56_ = NULL;
#line 199 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
	_data_->_tmp56_ = _data_->v6;
#line 199 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
	g_value_set_boxed (_data_->_tmp56_, _data_->dobj);
#line 200 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
	_data_->_tmp57_ = NULL;
#line 200 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
	_data_->_tmp57_ = folks_persona_store_detail_key (FOLKS_PERSONA_DETAIL_BIRTHDAY);
#line 200 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
	_data_->_tmp58_ = NULL;
#line 200 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
	_data_->_tmp58_ = g_strdup (_data_->_tmp57_);
#line 200 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
	_data_->_tmp59_ = NULL;
#line 200 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
	_data_->_tmp59_ = _data_->v6;
#line 200 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
	_data_->v6 = NULL;
#line 200 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
	g_hash_table_insert (_data_->details, _data_->_tmp58_, _data_->_tmp59_);
#line 203 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
	memset (&_data_->_tmp60_, 0, sizeof (GValue));
#line 203 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
	g_value_init (&_data_->_tmp60_, FOLKS_TYPE_GENDER);
#line 203 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
	memset (&_data_->_tmp61_, 0, sizeof (GValue));
#line 203 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
	_data_->_tmp61_ = _data_->_tmp60_;
#line 203 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
	_data_->_tmp62_ = NULL;
#line 203 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
	_data_->_tmp62_ = __g_value_dup0 (&_data_->_tmp61_);
#line 203 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
	_data_->_tmp63_ = NULL;
#line 203 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
	_data_->_tmp63_ = _data_->_tmp62_;
#line 203 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
	G_IS_VALUE (&_data_->_tmp61_) ? (g_value_unset (&_data_->_tmp61_), NULL) : NULL;
#line 203 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
	_data_->v7 = _data_->_tmp63_;
#line 204 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
	_data_->_tmp64_ = NULL;
#line 204 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
	_data_->_tmp64_ = _data_->v7;
#line 204 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
	g_value_set_enum (_data_->_tmp64_, (gint) FOLKS_GENDER_MALE);
#line 205 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
	_data_->_tmp65_ = NULL;
#line 205 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
	_data_->_tmp65_ = folks_persona_store_detail_key (FOLKS_PERSONA_DETAIL_GENDER);
#line 205 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
	_data_->_tmp66_ = NULL;
#line 205 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
	_data_->_tmp66_ = g_strdup (_data_->_tmp65_);
#line 205 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
	_data_->_tmp67_ = NULL;
#line 205 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
	_data_->_tmp67_ = _data_->v7;
#line 205 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
	_data_->v7 = NULL;
#line 205 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
	g_hash_table_insert (_data_->details, _data_->_tmp66_, _data_->_tmp67_);
#line 208 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
	memset (&_data_->_tmp68_, 0, sizeof (GValue));
#line 208 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
	g_value_init (&_data_->_tmp68_, GEE_TYPE_SET);
#line 208 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
	memset (&_data_->_tmp69_, 0, sizeof (GValue));
#line 208 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
	_data_->_tmp69_ = _data_->_tmp68_;
#line 208 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
	_data_->_tmp70_ = NULL;
#line 208 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
	_data_->_tmp70_ = __g_value_dup0 (&_data_->_tmp69_);
#line 208 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
	_data_->_tmp71_ = NULL;
#line 208 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
	_data_->_tmp71_ = _data_->_tmp70_;
#line 208 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
	G_IS_VALUE (&_data_->_tmp69_) ? (g_value_unset (&_data_->_tmp69_), NULL) : NULL;
#line 208 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
	_data_->v8 = _data_->_tmp71_;
#line 209 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
	_data_->_tmp72_ = NULL;
#line 209 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
	_data_->_tmp72_ = gee_hash_set_new (FOLKS_TYPE_EMAIL_FIELD_DETAILS, (GBoxedCopyFunc) g_object_ref, g_object_unref, _folks_abstract_field_details_hash_static_gee_hash_data_func, NULL, NULL, _folks_abstract_field_details_equal_static_gee_equal_data_func, NULL, NULL);
#line 209 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
	_data_->emails = _data_->_tmp72_;
#line 212 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
	_data_->_tmp73_ = NULL;
#line 212 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
	_data_->_tmp73_ = _data_->self->priv->_email_1;
#line 212 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
	_data_->_tmp74_ = NULL;
#line 212 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
	_data_->_tmp74_ = folks_email_field_details_new (_data_->_tmp73_, NULL);
#line 212 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
	_data_->email_1 = _data_->_tmp74_;
#line 213 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
	gee_abstract_collection_add ((GeeAbstractCollection*) _data_->emails, _data_->email_1);
#line 214 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
	_data_->_tmp75_ = NULL;
#line 214 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
	_data_->_tmp75_ = _data_->self->priv->_email_2;
#line 214 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
	_data_->_tmp76_ = NULL;
#line 214 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
	_data_->_tmp76_ = folks_email_field_details_new (_data_->_tmp75_, NULL);
#line 214 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
	_data_->email_2 = _data_->_tmp76_;
#line 215 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
	gee_abstract_collection_add ((GeeAbstractCollection*) _data_->emails, _data_->email_2);
#line 216 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
	_data_->_tmp77_ = NULL;
#line 216 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
	_data_->_tmp77_ = _data_->v8;
#line 216 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
	g_value_set_object (_data_->_tmp77_, (GObject*) _data_->emails);
#line 217 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
	_data_->_tmp78_ = NULL;
#line 217 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
	_data_->_tmp78_ = folks_persona_store_detail_key (FOLKS_PERSONA_DETAIL_EMAIL_ADDRESSES);
#line 217 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
	_data_->_tmp79_ = NULL;
#line 217 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
	_data_->_tmp79_ = g_strdup (_data_->_tmp78_);
#line 217 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
	_data_->_tmp80_ = NULL;
#line 217 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
	_data_->_tmp80_ = _data_->v8;
#line 217 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
	_data_->v8 = NULL;
#line 217 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
	g_hash_table_insert (_data_->details, _data_->_tmp79_, _data_->_tmp80_);
#line 221 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
	memset (&_data_->_tmp81_, 0, sizeof (GValue));
#line 221 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
	g_value_init (&_data_->_tmp81_, GEE_TYPE_MULTI_MAP);
#line 221 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
	memset (&_data_->_tmp82_, 0, sizeof (GValue));
#line 221 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
	_data_->_tmp82_ = _data_->_tmp81_;
#line 221 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
	_data_->_tmp83_ = NULL;
#line 221 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
	_data_->_tmp83_ = __g_value_dup0 (&_data_->_tmp82_);
#line 221 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
	_data_->_tmp84_ = NULL;
#line 221 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
	_data_->_tmp84_ = _data_->_tmp83_;
#line 221 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
	G_IS_VALUE (&_data_->_tmp82_) ? (g_value_unset (&_data_->_tmp82_), NULL) : NULL;
#line 221 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
	_data_->v9 = _data_->_tmp84_;
#line 222 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
	_data_->_tmp85_ = NULL;
#line 222 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
	_data_->_tmp85_ = gee_hash_multi_map_new (G_TYPE_STRING, (GBoxedCopyFunc) g_strdup, g_free, FOLKS_TYPE_IM_FIELD_DETAILS, (GBoxedCopyFunc) g_object_ref, g_object_unref, NULL, NULL, NULL, NULL, NULL, NULL, _folks_abstract_field_details_hash_static_gee_hash_data_func, NULL, NULL, _folks_abstract_field_details_equal_static_gee_equal_data_func, NULL, NULL);
#line 222 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
	_data_->im_addrs = _data_->_tmp85_;
#line 225 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
	_data_->_tmp86_ = NULL;
#line 225 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
	_data_->_tmp86_ = _data_->self->priv->_im_addr_1;
#line 225 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
	_data_->_tmp87_ = NULL;
#line 225 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
	_data_->_tmp87_ = folks_im_field_details_new (_data_->_tmp86_, NULL);
#line 225 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
	_data_->_tmp88_ = NULL;
#line 225 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
	_data_->_tmp88_ = _data_->_tmp87_;
#line 225 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
	gee_multi_map_set ((GeeMultiMap*) _data_->im_addrs, "jabber", _data_->_tmp88_);
#line 225 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
	_g_object_unref0 (_data_->_tmp88_);
#line 226 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
	_data_->_tmp89_ = NULL;
#line 226 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
	_data_->_tmp89_ = _data_->self->priv->_im_addr_2;
#line 226 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
	_data_->_tmp90_ = NULL;
#line 226 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
	_data_->_tmp90_ = folks_im_field_details_new (_data_->_tmp89_, NULL);
#line 226 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
	_data_->_tmp91_ = NULL;
#line 226 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
	_data_->_tmp91_ = _data_->_tmp90_;
#line 226 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
	gee_multi_map_set ((GeeMultiMap*) _data_->im_addrs, "yahoo", _data_->_tmp91_);
#line 226 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
	_g_object_unref0 (_data_->_tmp91_);
#line 227 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
	g_value_set_object (_data_->v9, (GObject*) _data_->im_addrs);
#line 228 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
	_data_->_tmp92_ = NULL;
#line 228 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
	_data_->_tmp92_ = folks_persona_store_detail_key (FOLKS_PERSONA_DETAIL_IM_ADDRESSES);
#line 228 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
	_data_->_tmp93_ = NULL;
#line 228 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
	_data_->_tmp93_ = g_strdup (_data_->_tmp92_);
#line 228 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
	_data_->_tmp94_ = NULL;
#line 228 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
	_data_->_tmp94_ = __g_value_dup0 (_data_->v9);
#line 228 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
	g_hash_table_insert (_data_->details, _data_->_tmp93_, _data_->_tmp94_);
#line 231 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
	memset (&_data_->_tmp95_, 0, sizeof (GValue));
#line 231 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
	g_value_init (&_data_->_tmp95_, GEE_TYPE_SET);
#line 231 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
	memset (&_data_->_tmp96_, 0, sizeof (GValue));
#line 231 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
	_data_->_tmp96_ = _data_->_tmp95_;
#line 231 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
	_data_->_tmp97_ = NULL;
#line 231 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
	_data_->_tmp97_ = __g_value_dup0 (&_data_->_tmp96_);
#line 231 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
	_data_->_tmp98_ = NULL;
#line 231 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
	_data_->_tmp98_ = _data_->_tmp97_;
#line 231 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
	G_IS_VALUE (&_data_->_tmp96_) ? (g_value_unset (&_data_->_tmp96_), NULL) : NULL;
#line 231 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
	_data_->v10 = _data_->_tmp98_;
#line 232 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
	_data_->_tmp99_ = NULL;
#line 232 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
	_data_->_tmp99_ = gee_hash_set_new (FOLKS_TYPE_NOTE_FIELD_DETAILS, (GBoxedCopyFunc) g_object_ref, g_object_unref, _folks_abstract_field_details_hash_static_gee_hash_data_func, NULL, NULL, _folks_abstract_field_details_equal_static_gee_equal_data_func, NULL, NULL);
#line 232 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
	_data_->notes = _data_->_tmp99_;
#line 235 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
	_data_->_tmp100_ = NULL;
#line 235 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
	_data_->_tmp100_ = _data_->self->priv->_note_1;
#line 235 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
	_data_->_tmp101_ = NULL;
#line 235 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
	_data_->_tmp101_ = folks_note_field_details_new (_data_->_tmp100_, NULL, NULL);
#line 235 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
	_data_->note_fd_1 = _data_->_tmp101_;
#line 236 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
	gee_abstract_collection_add ((GeeAbstractCollection*) _data_->notes, _data_->note_fd_1);
#line 237 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
	_data_->_tmp102_ = NULL;
#line 237 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
	_data_->_tmp102_ = _data_->v10;
#line 237 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
	g_value_set_object (_data_->_tmp102_, (GObject*) _data_->notes);
#line 238 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
	_data_->_tmp103_ = NULL;
#line 238 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
	_data_->_tmp103_ = folks_persona_store_detail_key (FOLKS_PERSONA_DETAIL_NOTES);
#line 238 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
	_data_->_tmp104_ = NULL;
#line 238 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
	_data_->_tmp104_ = g_strdup (_data_->_tmp103_);
#line 238 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
	_data_->_tmp105_ = NULL;
#line 238 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
	_data_->_tmp105_ = _data_->v10;
#line 238 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
	_data_->v10 = NULL;
#line 238 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
	g_hash_table_insert (_data_->details, _data_->_tmp104_, _data_->_tmp105_);
#line 241 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
	memset (&_data_->_tmp106_, 0, sizeof (GValue));
#line 241 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
	g_value_init (&_data_->_tmp106_, GEE_TYPE_SET);
#line 241 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
	memset (&_data_->_tmp107_, 0, sizeof (GValue));
#line 241 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
	_data_->_tmp107_ = _data_->_tmp106_;
#line 241 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
	_data_->_tmp108_ = NULL;
#line 241 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
	_data_->_tmp108_ = __g_value_dup0 (&_data_->_tmp107_);
#line 241 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
	_data_->_tmp109_ = NULL;
#line 241 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
	_data_->_tmp109_ = _data_->_tmp108_;
#line 241 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
	G_IS_VALUE (&_data_->_tmp107_) ? (g_value_unset (&_data_->_tmp107_), NULL) : NULL;
#line 241 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
	_data_->v11 = _data_->_tmp109_;
#line 242 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
	_data_->_tmp110_ = NULL;
#line 242 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
	_data_->_tmp110_ = gee_hash_set_new (FOLKS_TYPE_PHONE_FIELD_DETAILS, (GBoxedCopyFunc) g_object_ref, g_object_unref, _folks_abstract_field_details_hash_static_gee_hash_data_func, NULL, NULL, _folks_abstract_field_details_equal_static_gee_equal_data_func, NULL, NULL);
#line 242 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
	_data_->phones = _data_->_tmp110_;
#line 246 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
	_data_->_tmp111_ = NULL;
#line 246 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
	_data_->_tmp111_ = _data_->self->priv->_phone_1;
#line 246 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
	_data_->_tmp112_ = NULL;
#line 246 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
	_data_->_tmp112_ = folks_phone_field_details_new (_data_->_tmp111_, NULL);
#line 246 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
	_data_->phone_1 = _data_->_tmp112_;
#line 247 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
	gee_abstract_collection_add ((GeeAbstractCollection*) _data_->phones, _data_->phone_1);
#line 248 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
	_data_->_tmp113_ = NULL;
#line 248 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
	_data_->_tmp113_ = _data_->self->priv->_phone_2;
#line 248 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
	_data_->_tmp114_ = NULL;
#line 248 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
	_data_->_tmp114_ = folks_phone_field_details_new (_data_->_tmp113_, NULL);
#line 248 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
	_data_->phone_2 = _data_->_tmp114_;
#line 249 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
	gee_abstract_collection_add ((GeeAbstractCollection*) _data_->phones, _data_->phone_2);
#line 250 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
	_data_->_tmp115_ = NULL;
#line 250 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
	_data_->_tmp115_ = _data_->v11;
#line 250 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
	g_value_set_object (_data_->_tmp115_, (GObject*) _data_->phones);
#line 251 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
	_data_->_tmp116_ = NULL;
#line 251 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
	_data_->_tmp116_ = folks_persona_store_detail_key (FOLKS_PERSONA_DETAIL_PHONE_NUMBERS);
#line 251 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
	_data_->_tmp117_ = NULL;
#line 251 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
	_data_->_tmp117_ = g_strdup (_data_->_tmp116_);
#line 251 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
	_data_->_tmp118_ = NULL;
#line 251 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
	_data_->_tmp118_ = _data_->v11;
#line 251 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
	_data_->v11 = NULL;
#line 251 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
	g_hash_table_insert (_data_->details, _data_->_tmp117_, _data_->_tmp118_);
#line 255 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
	memset (&_data_->_tmp119_, 0, sizeof (GValue));
#line 255 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
	g_value_init (&_data_->_tmp119_, GEE_TYPE_SET);
#line 255 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
	memset (&_data_->_tmp120_, 0, sizeof (GValue));
#line 255 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
	_data_->_tmp120_ = _data_->_tmp119_;
#line 255 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
	_data_->_tmp121_ = NULL;
#line 255 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
	_data_->_tmp121_ = __g_value_dup0 (&_data_->_tmp120_);
#line 255 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
	_data_->_tmp122_ = NULL;
#line 255 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
	_data_->_tmp122_ = _data_->_tmp121_;
#line 255 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
	G_IS_VALUE (&_data_->_tmp120_) ? (g_value_unset (&_data_->_tmp120_), NULL) : NULL;
#line 255 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
	_data_->v12 = _data_->_tmp122_;
#line 256 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
	_data_->_tmp123_ = NULL;
#line 256 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
	_data_->_tmp123_ = gee_hash_set_new (FOLKS_TYPE_ROLE_FIELD_DETAILS, (GBoxedCopyFunc) g_object_ref, g_object_unref, _folks_abstract_field_details_hash_static_gee_hash_data_func, NULL, NULL, _folks_abstract_field_details_equal_static_gee_equal_data_func, NULL, NULL);
#line 256 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
	_data_->role_fds = _data_->_tmp123_;
#line 259 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
	_data_->_tmp124_ = NULL;
#line 259 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
	_data_->_tmp124_ = _data_->self->priv->_title_1;
#line 259 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
	_data_->_tmp125_ = NULL;
#line 259 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
	_data_->_tmp125_ = _data_->self->priv->_organisation_1;
#line 259 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
	_data_->_tmp126_ = NULL;
#line 259 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
	_data_->_tmp126_ = folks_role_new (_data_->_tmp124_, _data_->_tmp125_, NULL);
#line 259 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
	_data_->r1 = _data_->_tmp126_;
#line 260 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
	_data_->_tmp127_ = NULL;
#line 260 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
	_data_->_tmp127_ = _data_->self->priv->_role_1;
#line 260 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
	folks_role_set_role (_data_->r1, _data_->_tmp127_);
#line 261 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
	_data_->_tmp128_ = NULL;
#line 261 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
	_data_->_tmp128_ = folks_role_field_details_new (_data_->r1, NULL);
#line 261 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
	_data_->role_fd1 = _data_->_tmp128_;
#line 262 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
	gee_abstract_collection_add ((GeeAbstractCollection*) _data_->role_fds, _data_->role_fd1);
#line 263 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
	_data_->_tmp129_ = NULL;
#line 263 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
	_data_->_tmp129_ = _data_->v12;
#line 263 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
	g_value_set_object (_data_->_tmp129_, (GObject*) _data_->role_fds);
#line 264 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
	_data_->_tmp130_ = NULL;
#line 264 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
	_data_->_tmp130_ = folks_persona_store_detail_key (FOLKS_PERSONA_DETAIL_ROLES);
#line 264 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
	_data_->_tmp131_ = NULL;
#line 264 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
	_data_->_tmp131_ = g_strdup (_data_->_tmp130_);
#line 264 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
	_data_->_tmp132_ = NULL;
#line 264 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
	_data_->_tmp132_ = _data_->v12;
#line 264 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
	_data_->v12 = NULL;
#line 264 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
	g_hash_table_insert (_data_->details, _data_->_tmp131_, _data_->_tmp132_);
#line 267 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
	memset (&_data_->_tmp133_, 0, sizeof (GValue));
#line 267 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
	g_value_init (&_data_->_tmp133_, GEE_TYPE_SET);
#line 267 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
	memset (&_data_->_tmp134_, 0, sizeof (GValue));
#line 267 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
	_data_->_tmp134_ = _data_->_tmp133_;
#line 267 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
	_data_->_tmp135_ = NULL;
#line 267 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
	_data_->_tmp135_ = __g_value_dup0 (&_data_->_tmp134_);
#line 267 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
	_data_->_tmp136_ = NULL;
#line 267 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
	_data_->_tmp136_ = _data_->_tmp135_;
#line 267 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
	G_IS_VALUE (&_data_->_tmp134_) ? (g_value_unset (&_data_->_tmp134_), NULL) : NULL;
#line 267 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
	_data_->v13 = _data_->_tmp136_;
#line 268 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
	_data_->_tmp137_ = NULL;
#line 268 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
	_data_->_tmp137_ = gee_hash_set_new (FOLKS_TYPE_POSTAL_ADDRESS_FIELD_DETAILS, (GBoxedCopyFunc) g_object_ref, g_object_unref, _folks_abstract_field_details_hash_static_gee_hash_data_func, NULL, NULL, _folks_abstract_field_details_equal_static_gee_equal_data_func, NULL, NULL);
#line 268 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
	_data_->postal_addresses = _data_->_tmp137_;
#line 272 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
	_data_->_tmp138_ = NULL;
#line 272 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
	_data_->_tmp138_ = _data_->self->priv->_po_box;
#line 272 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
	_data_->_tmp139_ = NULL;
#line 272 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
	_data_->_tmp139_ = _data_->self->priv->_extension;
#line 272 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
	_data_->_tmp140_ = NULL;
#line 272 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
	_data_->_tmp140_ = _data_->self->priv->_street;
#line 272 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
	_data_->_tmp141_ = NULL;
#line 272 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
	_data_->_tmp141_ = _data_->self->priv->_locality;
#line 272 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
	_data_->_tmp142_ = NULL;
#line 272 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
	_data_->_tmp142_ = _data_->self->priv->_region;
#line 272 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
	_data_->_tmp143_ = NULL;
#line 272 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
	_data_->_tmp143_ = _data_->self->priv->_postal_code;
#line 272 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
	_data_->_tmp144_ = NULL;
#line 272 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
	_data_->_tmp144_ = _data_->self->priv->_country;
#line 272 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
	_data_->_tmp145_ = NULL;
#line 272 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
	_data_->_tmp145_ = folks_postal_address_new (_data_->_tmp138_, _data_->_tmp139_, _data_->_tmp140_, _data_->_tmp141_, _data_->_tmp142_, _data_->_tmp143_, _data_->_tmp144_, NULL, NULL);
#line 272 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
	_data_->postal_a = _data_->_tmp145_;
#line 275 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
	_data_->_tmp146_ = NULL;
#line 275 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
	_data_->_tmp146_ = folks_postal_address_field_details_new (_data_->postal_a, NULL);
#line 275 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
	_data_->postal_a_fd = _data_->_tmp146_;
#line 276 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
	gee_abstract_collection_add ((GeeAbstractCollection*) _data_->postal_addresses, _data_->postal_a_fd);
#line 277 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
	_data_->_tmp147_ = NULL;
#line 277 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
	_data_->_tmp147_ = _data_->v13;
#line 277 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
	g_value_set_object (_data_->_tmp147_, (GObject*) _data_->postal_addresses);
#line 278 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
	_data_->_tmp148_ = NULL;
#line 278 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
	_data_->_tmp148_ = folks_persona_store_detail_key (FOLKS_PERSONA_DETAIL_POSTAL_ADDRESSES);
#line 278 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
	_data_->_tmp149_ = NULL;
#line 278 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
	_data_->_tmp149_ = g_strdup (_data_->_tmp148_);
#line 278 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
	_data_->_tmp150_ = NULL;
#line 278 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
	_data_->_tmp150_ = _data_->v13;
#line 278 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
	_data_->v13 = NULL;
#line 278 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
	g_hash_table_insert (_data_->details, _data_->_tmp149_, _data_->_tmp150_);
#line 282 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
	memset (&_data_->_tmp151_, 0, sizeof (GValue));
#line 282 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
	g_value_init (&_data_->_tmp151_, GEE_TYPE_SET);
#line 282 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
	memset (&_data_->_tmp152_, 0, sizeof (GValue));
#line 282 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
	_data_->_tmp152_ = _data_->_tmp151_;
#line 282 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
	_data_->_tmp153_ = NULL;
#line 282 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
	_data_->_tmp153_ = __g_value_dup0 (&_data_->_tmp152_);
#line 282 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
	_data_->_tmp154_ = NULL;
#line 282 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
	_data_->_tmp154_ = _data_->_tmp153_;
#line 282 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
	G_IS_VALUE (&_data_->_tmp152_) ? (g_value_unset (&_data_->_tmp152_), NULL) : NULL;
#line 282 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
	_data_->v14 = _data_->_tmp154_;
#line 283 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
	_data_->_tmp155_ = NULL;
#line 283 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
	_data_->_tmp155_ = gee_hash_set_new (FOLKS_TYPE_URL_FIELD_DETAILS, (GBoxedCopyFunc) g_object_ref, g_object_unref, _folks_abstract_field_details_hash_static_gee_hash_data_func, NULL, NULL, _folks_abstract_field_details_equal_static_gee_equal_data_func, NULL, NULL);
#line 283 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
	_data_->urls = _data_->_tmp155_;
#line 286 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
	_data_->_tmp156_ = NULL;
#line 286 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
	_data_->_tmp156_ = _data_->self->priv->_url_1;
#line 286 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
	_data_->_tmp157_ = NULL;
#line 286 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
	_data_->_tmp157_ = folks_url_field_details_new (_data_->_tmp156_, NULL);
#line 286 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
	_data_->url_1 = _data_->_tmp157_;
#line 287 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
	gee_abstract_collection_add ((GeeAbstractCollection*) _data_->urls, _data_->url_1);
#line 288 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
	_data_->_tmp158_ = NULL;
#line 288 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
	_data_->_tmp158_ = _data_->self->priv->_url_2;
#line 288 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
	_data_->_tmp159_ = NULL;
#line 288 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
	_data_->_tmp159_ = folks_url_field_details_new (_data_->_tmp158_, NULL);
#line 288 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
	_data_->url_2 = _data_->_tmp159_;
#line 289 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
	gee_abstract_collection_add ((GeeAbstractCollection*) _data_->urls, _data_->url_2);
#line 290 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
	_data_->_tmp160_ = NULL;
#line 290 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
	_data_->_tmp160_ = _data_->v14;
#line 290 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
	g_value_set_object (_data_->_tmp160_, (GObject*) _data_->urls);
#line 291 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
	_data_->_tmp161_ = NULL;
#line 291 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
	_data_->_tmp161_ = folks_persona_store_detail_key (FOLKS_PERSONA_DETAIL_URLS);
#line 291 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
	_data_->_tmp162_ = NULL;
#line 291 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
	_data_->_tmp162_ = g_strdup (_data_->_tmp161_);
#line 291 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
	_data_->_tmp163_ = NULL;
#line 291 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
	_data_->_tmp163_ = _data_->v14;
#line 291 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
	_data_->v14 = NULL;
#line 291 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
	g_hash_table_insert (_data_->details, _data_->_tmp162_, _data_->_tmp163_);
#line 2151 "add-persona.c"
	{
#line 297 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
		_data_->_tmp165_ = NULL;
#line 297 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
		_data_->_tmp165_ = _data_->self->priv->_aggregator;
#line 297 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
		_data_->_tmp166_ = NULL;
#line 297 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
		_data_->_tmp166_ = _data_->self->priv->_pstore;
#line 297 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
		_data_->_state_ = 1;
#line 297 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
		folks_individual_aggregator_add_persona_from_details (_data_->_tmp165_, NULL, (FolksPersonaStore*) _data_->_tmp166_, _data_->details, _add_persona_tests_add_persona_ready, _data_);
#line 297 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
		return FALSE;
#line 2167 "add-persona.c"
		_state_1:
#line 297 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
		_data_->_tmp167_ = NULL;
#line 297 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
		_data_->_tmp167_ = folks_individual_aggregator_add_persona_from_details_finish (_data_->_tmp165_, _data_->_res_, &_data_->_inner_error_);
#line 297 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
		_data_->_tmp164_ = _data_->_tmp167_;
#line 297 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
		if (G_UNLIKELY (_data_->_inner_error_ != NULL)) {
#line 297 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
			if (_data_->_inner_error_->domain == FOLKS_INDIVIDUAL_AGGREGATOR_ERROR) {
#line 2179 "add-persona.c"
				goto __catch1_folks_individual_aggregator_error;
			}
#line 297 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
			_g_object_unref0 (_data_->url_2);
#line 297 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
			_g_object_unref0 (_data_->url_1);
#line 297 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
			_g_object_unref0 (_data_->urls);
#line 297 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
			__vala_GValue_free0 (_data_->v14);
#line 297 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
			_g_object_unref0 (_data_->postal_a_fd);
#line 297 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
			_g_object_unref0 (_data_->postal_a);
#line 297 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
			_g_object_unref0 (_data_->postal_addresses);
#line 297 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
			__vala_GValue_free0 (_data_->v13);
#line 297 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
			_g_object_unref0 (_data_->role_fd1);
#line 297 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
			_g_object_unref0 (_data_->r1);
#line 297 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
			_g_object_unref0 (_data_->role_fds);
#line 297 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
			__vala_GValue_free0 (_data_->v12);
#line 297 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
			_g_object_unref0 (_data_->phone_2);
#line 297 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
			_g_object_unref0 (_data_->phone_1);
#line 297 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
			_g_object_unref0 (_data_->phones);
#line 297 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
			__vala_GValue_free0 (_data_->v11);
#line 297 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
			_g_object_unref0 (_data_->note_fd_1);
#line 297 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
			_g_object_unref0 (_data_->notes);
#line 297 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
			__vala_GValue_free0 (_data_->v10);
#line 297 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
			_g_object_unref0 (_data_->im_addrs);
#line 297 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
			__vala_GValue_free0 (_data_->v9);
#line 297 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
			_g_object_unref0 (_data_->email_2);
#line 297 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
			_g_object_unref0 (_data_->email_1);
#line 297 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
			_g_object_unref0 (_data_->emails);
#line 297 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
			__vala_GValue_free0 (_data_->v8);
#line 297 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
			__vala_GValue_free0 (_data_->v7);
#line 297 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
			_g_date_time_unref0 (_data_->dobj);
#line 297 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
			__vala_GValue_free0 (_data_->v6);
#line 297 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
			__vala_GValue_free0 (_data_->v5);
#line 297 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
			_g_object_unref0 (_data_->sname);
#line 297 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
			__vala_GValue_free0 (_data_->v4);
#line 297 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
			__vala_GValue_free0 (_data_->v3);
#line 297 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
			__vala_GValue_free0 (_data_->v2);
#line 297 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
			__vala_GValue_free0 (_data_->v1);
#line 297 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
			_g_hash_table_unref0 (_data_->details);
#line 297 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
			g_critical ("file %s: line %d: unexpected error: %s (%s, %d)", __FILE__, __LINE__, _data_->_inner_error_->message, g_quark_to_string (_data_->_inner_error_->domain), _data_->_inner_error_->code);
#line 297 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
			g_clear_error (&_data_->_inner_error_);
#line 297 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
			return FALSE;
#line 2258 "add-persona.c"
		}
#line 296 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
		_data_->_tmp168_ = NULL;
#line 296 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
		_data_->_tmp168_ = _data_->_tmp164_;
#line 296 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
		_data_->_tmp164_ = NULL;
#line 296 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
		_data_->persona = G_TYPE_CHECK_INSTANCE_CAST (_data_->_tmp168_, TRF_TYPE_PERSONA, TrfPersona);
#line 299 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
		_data_->_tmp169_ = NULL;
#line 299 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
		_data_->_tmp169_ = _data_->persona;
#line 299 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
		_data_->_tmp170_ = NULL;
#line 299 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
		_data_->_tmp170_ = folks_persona_get_iid ((FolksPersona*) _data_->_tmp169_);
#line 299 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
		_data_->_tmp171_ = NULL;
#line 299 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
		_data_->_tmp171_ = _data_->_tmp170_;
#line 299 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
		_data_->_tmp172_ = NULL;
#line 299 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
		_data_->_tmp172_ = g_strdup (_data_->_tmp171_);
#line 299 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
		_g_free0 (_data_->self->priv->_persona_iid);
#line 299 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
		_data_->self->priv->_persona_iid = _data_->_tmp172_;
#line 294 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
		_g_object_unref0 (_data_->persona);
#line 294 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
		_g_object_unref0 (_data_->_tmp164_);
#line 2292 "add-persona.c"
	}
	goto __finally1;
	__catch1_folks_individual_aggregator_error:
	{
#line 294 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
		_data_->e = _data_->_inner_error_;
#line 294 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
		_data_->_inner_error_ = NULL;
#line 303 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
		_data_->_tmp173_ = NULL;
#line 303 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
		_data_->_tmp173_ = _data_->e;
#line 303 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
		_data_->_tmp174_ = NULL;
#line 303 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
		_data_->_tmp174_ = _data_->_tmp173_->message;
#line 303 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
		g_warning ("add-persona.vala:303: [AddPersonaError] add_persona_from_details: %s\n", _data_->_tmp174_);
#line 294 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
		_g_error_free0 (_data_->e);
#line 2313 "add-persona.c"
	}
	__finally1:
#line 294 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
	if (G_UNLIKELY (_data_->_inner_error_ != NULL)) {
#line 294 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
		_g_object_unref0 (_data_->url_2);
#line 294 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
		_g_object_unref0 (_data_->url_1);
#line 294 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
		_g_object_unref0 (_data_->urls);
#line 294 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
		__vala_GValue_free0 (_data_->v14);
#line 294 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
		_g_object_unref0 (_data_->postal_a_fd);
#line 294 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
		_g_object_unref0 (_data_->postal_a);
#line 294 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
		_g_object_unref0 (_data_->postal_addresses);
#line 294 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
		__vala_GValue_free0 (_data_->v13);
#line 294 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
		_g_object_unref0 (_data_->role_fd1);
#line 294 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
		_g_object_unref0 (_data_->r1);
#line 294 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
		_g_object_unref0 (_data_->role_fds);
#line 294 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
		__vala_GValue_free0 (_data_->v12);
#line 294 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
		_g_object_unref0 (_data_->phone_2);
#line 294 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
		_g_object_unref0 (_data_->phone_1);
#line 294 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
		_g_object_unref0 (_data_->phones);
#line 294 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
		__vala_GValue_free0 (_data_->v11);
#line 294 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
		_g_object_unref0 (_data_->note_fd_1);
#line 294 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
		_g_object_unref0 (_data_->notes);
#line 294 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
		__vala_GValue_free0 (_data_->v10);
#line 294 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
		_g_object_unref0 (_data_->im_addrs);
#line 294 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
		__vala_GValue_free0 (_data_->v9);
#line 294 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
		_g_object_unref0 (_data_->email_2);
#line 294 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
		_g_object_unref0 (_data_->email_1);
#line 294 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
		_g_object_unref0 (_data_->emails);
#line 294 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
		__vala_GValue_free0 (_data_->v8);
#line 294 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
		__vala_GValue_free0 (_data_->v7);
#line 294 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
		_g_date_time_unref0 (_data_->dobj);
#line 294 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
		__vala_GValue_free0 (_data_->v6);
#line 294 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
		__vala_GValue_free0 (_data_->v5);
#line 294 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
		_g_object_unref0 (_data_->sname);
#line 294 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
		__vala_GValue_free0 (_data_->v4);
#line 294 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
		__vala_GValue_free0 (_data_->v3);
#line 294 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
		__vala_GValue_free0 (_data_->v2);
#line 294 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
		__vala_GValue_free0 (_data_->v1);
#line 294 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
		_g_hash_table_unref0 (_data_->details);
#line 294 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _data_->_inner_error_->message, g_quark_to_string (_data_->_inner_error_->domain), _data_->_inner_error_->code);
#line 294 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
		g_clear_error (&_data_->_inner_error_);
#line 294 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
		return FALSE;
#line 2394 "add-persona.c"
	}
#line 161 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
	_g_object_unref0 (_data_->url_2);
#line 161 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
	_g_object_unref0 (_data_->url_1);
#line 161 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
	_g_object_unref0 (_data_->urls);
#line 161 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
	__vala_GValue_free0 (_data_->v14);
#line 161 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
	_g_object_unref0 (_data_->postal_a_fd);
#line 161 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
	_g_object_unref0 (_data_->postal_a);
#line 161 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
	_g_object_unref0 (_data_->postal_addresses);
#line 161 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
	__vala_GValue_free0 (_data_->v13);
#line 161 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
	_g_object_unref0 (_data_->role_fd1);
#line 161 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
	_g_object_unref0 (_data_->r1);
#line 161 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
	_g_object_unref0 (_data_->role_fds);
#line 161 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
	__vala_GValue_free0 (_data_->v12);
#line 161 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
	_g_object_unref0 (_data_->phone_2);
#line 161 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
	_g_object_unref0 (_data_->phone_1);
#line 161 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
	_g_object_unref0 (_data_->phones);
#line 161 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
	__vala_GValue_free0 (_data_->v11);
#line 161 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
	_g_object_unref0 (_data_->note_fd_1);
#line 161 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
	_g_object_unref0 (_data_->notes);
#line 161 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
	__vala_GValue_free0 (_data_->v10);
#line 161 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
	_g_object_unref0 (_data_->im_addrs);
#line 161 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
	__vala_GValue_free0 (_data_->v9);
#line 161 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
	_g_object_unref0 (_data_->email_2);
#line 161 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
	_g_object_unref0 (_data_->email_1);
#line 161 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
	_g_object_unref0 (_data_->emails);
#line 161 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
	__vala_GValue_free0 (_data_->v8);
#line 161 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
	__vala_GValue_free0 (_data_->v7);
#line 161 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
	_g_date_time_unref0 (_data_->dobj);
#line 161 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
	__vala_GValue_free0 (_data_->v6);
#line 161 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
	__vala_GValue_free0 (_data_->v5);
#line 161 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
	_g_object_unref0 (_data_->sname);
#line 161 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
	__vala_GValue_free0 (_data_->v4);
#line 161 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
	__vala_GValue_free0 (_data_->v3);
#line 161 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
	__vala_GValue_free0 (_data_->v2);
#line 161 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
	__vala_GValue_free0 (_data_->v1);
#line 161 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
	_g_hash_table_unref0 (_data_->details);
#line 161 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
	if (_data_->_state_ == 0) {
#line 161 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
		g_simple_async_result_complete_in_idle (_data_->_async_result);
#line 2470 "add-persona.c"
	} else {
#line 161 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
		g_simple_async_result_complete (_data_->_async_result);
#line 2474 "add-persona.c"
	}
#line 161 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
	g_object_unref (_data_->_async_result);
#line 161 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
	return FALSE;
#line 2480 "add-persona.c"
}


static void __add_persona_tests_notify_persona_sname_g_object_notify (GObject* _sender, GParamSpec* pspec, gpointer self) {
#line 329 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
	_add_persona_tests_notify_persona_sname ((AddPersonaTests*) self, _sender, pspec);
#line 2487 "add-persona.c"
}


static void __add_persona_tests_notify_cb_g_object_notify (GObject* _sender, GParamSpec* pspec, gpointer self) {
#line 334 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
	_add_persona_tests_notify_cb ((AddPersonaTests*) self, _sender, pspec);
#line 2494 "add-persona.c"
}


static void _add_persona_tests_individuals_changed_cb (AddPersonaTests* self, GeeMultiMap* changes) {
	GeeCollection* added = NULL;
	GeeMultiMap* _tmp0_ = NULL;
	GeeCollection* _tmp1_ = NULL;
#line 308 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
	g_return_if_fail (self != NULL);
#line 308 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
	g_return_if_fail (changes != NULL);
#line 311 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
	_tmp0_ = changes;
#line 311 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
	_tmp1_ = gee_multi_map_get_values (_tmp0_);
#line 311 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
	added = _tmp1_;
#line 2512 "add-persona.c"
	{
		GeeIterator* _i_it = NULL;
		GeeCollection* _tmp2_ = NULL;
		GeeIterator* _tmp3_ = NULL;
#line 313 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
		_tmp2_ = added;
#line 313 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
		_tmp3_ = gee_iterable_iterator ((GeeIterable*) _tmp2_);
#line 313 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
		_i_it = _tmp3_;
#line 313 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
		while (TRUE) {
#line 2525 "add-persona.c"
			GeeIterator* _tmp4_ = NULL;
			gboolean _tmp5_ = FALSE;
			FolksIndividual* i = NULL;
			GeeIterator* _tmp6_ = NULL;
			gpointer _tmp7_ = NULL;
			FolksIndividual* _tmp8_ = NULL;
			FolksIndividual* _tmp9_ = NULL;
			gboolean _tmp10_ = FALSE;
			gboolean _tmp11_ = FALSE;
#line 313 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
			_tmp4_ = _i_it;
#line 313 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
			_tmp5_ = gee_iterator_next (_tmp4_);
#line 313 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
			if (!_tmp5_) {
#line 313 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
				break;
#line 2543 "add-persona.c"
			}
#line 313 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
			_tmp6_ = _i_it;
#line 313 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
			_tmp7_ = gee_iterator_get (_tmp6_);
#line 313 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
			i = (FolksIndividual*) _tmp7_;
#line 315 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
			_tmp8_ = i;
#line 315 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
			_vala_assert (_tmp8_ != NULL, "i != null");
#line 317 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
			_tmp9_ = i;
#line 317 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
			_tmp10_ = folks_individual_get_is_user (_tmp9_);
#line 317 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
			_tmp11_ = _tmp10_;
#line 317 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
			if (_tmp11_ == FALSE) {
#line 2563 "add-persona.c"
				FolksIndividual* _tmp26_ = NULL;
				FolksIndividual* _tmp27_ = NULL;
				FolksIndividual* _tmp28_ = NULL;
				FolksIndividual* _tmp29_ = NULL;
				FolksIndividual* _tmp30_ = NULL;
				FolksIndividual* _tmp31_ = NULL;
				FolksIndividual* _tmp32_ = NULL;
				FolksIndividual* _tmp33_ = NULL;
				FolksIndividual* _tmp34_ = NULL;
				FolksIndividual* _tmp35_ = NULL;
				FolksIndividual* _tmp36_ = NULL;
				FolksIndividual* _tmp37_ = NULL;
				FolksIndividual* _tmp38_ = NULL;
				FolksIndividual* _tmp39_ = NULL;
				FolksIndividual* _tmp40_ = NULL;
				FolksIndividual* _tmp41_ = NULL;
				FolksIndividual* _tmp42_ = NULL;
				FolksIndividual* _tmp43_ = NULL;
				{
					GeeIterator* _p_it = NULL;
					FolksIndividual* _tmp12_ = NULL;
					GeeSet* _tmp13_ = NULL;
					GeeSet* _tmp14_ = NULL;
					GeeIterator* _tmp15_ = NULL;
#line 324 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
					_tmp12_ = i;
#line 324 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
					_tmp13_ = folks_individual_get_personas (_tmp12_);
#line 324 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
					_tmp14_ = _tmp13_;
#line 324 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
					_tmp15_ = gee_iterable_iterator ((GeeIterable*) _tmp14_);
#line 324 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
					_p_it = _tmp15_;
#line 324 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
					while (TRUE) {
#line 2600 "add-persona.c"
						GeeIterator* _tmp16_ = NULL;
						gboolean _tmp17_ = FALSE;
						FolksPersona* p = NULL;
						GeeIterator* _tmp18_ = NULL;
						gpointer _tmp19_ = NULL;
						gboolean _tmp20_ = FALSE;
						FolksPersona* _tmp21_ = NULL;
#line 324 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
						_tmp16_ = _p_it;
#line 324 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
						_tmp17_ = gee_iterator_next (_tmp16_);
#line 324 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
						if (!_tmp17_) {
#line 324 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
							break;
#line 2616 "add-persona.c"
						}
#line 324 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
						_tmp18_ = _p_it;
#line 324 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
						_tmp19_ = gee_iterator_get (_tmp18_);
#line 324 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
						p = (FolksPersona*) _tmp19_;
#line 326 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
						_tmp21_ = p;
#line 326 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
						if (G_TYPE_CHECK_INSTANCE_TYPE (_tmp21_, FOLKS_TYPE_NAME_DETAILS)) {
#line 2628 "add-persona.c"
							FolksPersona* _tmp22_ = NULL;
							FolksStructuredName* _tmp23_ = NULL;
							FolksStructuredName* _tmp24_ = NULL;
#line 327 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
							_tmp22_ = p;
#line 327 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
							_tmp23_ = folks_name_details_get_structured_name (G_TYPE_CHECK_INSTANCE_CAST (_tmp22_, FOLKS_TYPE_NAME_DETAILS, FolksNameDetails));
#line 327 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
							_tmp24_ = _tmp23_;
#line 327 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
							_tmp20_ = _tmp24_ != NULL;
#line 2640 "add-persona.c"
						} else {
#line 326 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
							_tmp20_ = FALSE;
#line 2644 "add-persona.c"
						}
#line 326 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
						if (_tmp20_) {
#line 2648 "add-persona.c"
							FolksPersona* _tmp25_ = NULL;
#line 329 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
							_tmp25_ = p;
#line 329 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
							g_signal_connect_object ((GObject*) _tmp25_, "notify::structured-name", (GCallback) __add_persona_tests_notify_persona_sname_g_object_notify, self, 0);
#line 2654 "add-persona.c"
						}
#line 324 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
						_g_object_unref0 (p);
#line 2658 "add-persona.c"
					}
#line 324 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
					_g_object_unref0 (_p_it);
#line 2662 "add-persona.c"
				}
#line 334 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
				_tmp26_ = i;
#line 334 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
				g_signal_connect_object ((GObject*) _tmp26_, "notify::full-name", (GCallback) __add_persona_tests_notify_cb_g_object_notify, self, 0);
#line 335 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
				_tmp27_ = i;
#line 335 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
				g_signal_connect_object ((GObject*) _tmp27_, "notify::nickname", (GCallback) __add_persona_tests_notify_cb_g_object_notify, self, 0);
#line 336 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
				_tmp28_ = i;
#line 336 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
				g_signal_connect_object ((GObject*) _tmp28_, "notify::avatar", (GCallback) __add_persona_tests_notify_cb_g_object_notify, self, 0);
#line 337 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
				_tmp29_ = i;
#line 337 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
				g_signal_connect_object ((GObject*) _tmp29_, "notify::is-favourite", (GCallback) __add_persona_tests_notify_cb_g_object_notify, self, 0);
#line 338 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
				_tmp30_ = i;
#line 338 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
				g_signal_connect_object ((GObject*) _tmp30_, "notify::structured-name", (GCallback) __add_persona_tests_notify_cb_g_object_notify, self, 0);
#line 339 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
				_tmp31_ = i;
#line 339 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
				g_signal_connect_object ((GObject*) _tmp31_, "notify::family-name", (GCallback) __add_persona_tests_notify_cb_g_object_notify, self, 0);
#line 340 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
				_tmp32_ = i;
#line 340 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
				g_signal_connect_object ((GObject*) _tmp32_, "notify::given-name", (GCallback) __add_persona_tests_notify_cb_g_object_notify, self, 0);
#line 341 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
				_tmp33_ = i;
#line 341 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
				g_signal_connect_object ((GObject*) _tmp33_, "notify::avatar", (GCallback) __add_persona_tests_notify_cb_g_object_notify, self, 0);
#line 342 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
				_tmp34_ = i;
#line 342 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
				g_signal_connect_object ((GObject*) _tmp34_, "notify::birthday", (GCallback) __add_persona_tests_notify_cb_g_object_notify, self, 0);
#line 343 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
				_tmp35_ = i;
#line 343 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
				g_signal_connect_object ((GObject*) _tmp35_, "notify::gender", (GCallback) __add_persona_tests_notify_cb_g_object_notify, self, 0);
#line 344 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
				_tmp36_ = i;
#line 344 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
				g_signal_connect_object ((GObject*) _tmp36_, "notify::email-addresses", (GCallback) __add_persona_tests_notify_cb_g_object_notify, self, 0);
#line 345 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
				_tmp37_ = i;
#line 345 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
				g_signal_connect_object ((GObject*) _tmp37_, "notify::im-addresses", (GCallback) __add_persona_tests_notify_cb_g_object_notify, self, 0);
#line 346 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
				_tmp38_ = i;
#line 346 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
				g_signal_connect_object ((GObject*) _tmp38_, "notify::notes", (GCallback) __add_persona_tests_notify_cb_g_object_notify, self, 0);
#line 347 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
				_tmp39_ = i;
#line 347 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
				g_signal_connect_object ((GObject*) _tmp39_, "notify::phone-numbers", (GCallback) __add_persona_tests_notify_cb_g_object_notify, self, 0);
#line 348 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
				_tmp40_ = i;
#line 348 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
				g_signal_connect_object ((GObject*) _tmp40_, "notify::roles", (GCallback) __add_persona_tests_notify_cb_g_object_notify, self, 0);
#line 349 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
				_tmp41_ = i;
#line 349 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
				g_signal_connect_object ((GObject*) _tmp41_, "notify::postal-addresses", (GCallback) __add_persona_tests_notify_cb_g_object_notify, self, 0);
#line 350 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
				_tmp42_ = i;
#line 350 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
				g_signal_connect_object ((GObject*) _tmp42_, "notify::urls", (GCallback) __add_persona_tests_notify_cb_g_object_notify, self, 0);
#line 352 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
				_tmp43_ = i;
#line 352 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
				_add_persona_tests_check_properties (self, _tmp43_);
#line 2736 "add-persona.c"
			}
#line 313 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
			_g_object_unref0 (i);
#line 2740 "add-persona.c"
		}
#line 313 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
		_g_object_unref0 (_i_it);
#line 2744 "add-persona.c"
	}
#line 308 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
	_g_object_unref0 (added);
#line 2748 "add-persona.c"
}


static void _add_persona_tests_notify_cb (AddPersonaTests* self, GObject* individual_obj, GParamSpec* ps) {
	FolksIndividual* i = NULL;
	GObject* _tmp0_ = NULL;
	FolksIndividual* _tmp1_ = NULL;
#line 357 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
	g_return_if_fail (self != NULL);
#line 357 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
	g_return_if_fail (individual_obj != NULL);
#line 357 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
	g_return_if_fail (ps != NULL);
#line 359 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
	_tmp0_ = individual_obj;
#line 359 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
	_tmp1_ = _g_object_ref0 (G_TYPE_CHECK_INSTANCE_CAST (_tmp0_, FOLKS_TYPE_INDIVIDUAL, FolksIndividual));
#line 359 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
	i = _tmp1_;
#line 360 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
	_add_persona_tests_check_properties (self, i);
#line 357 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
	_g_object_unref0 (i);
#line 2772 "add-persona.c"
}


static void _add_persona_tests_notify_persona_sname (AddPersonaTests* self, GObject* persona_p, GParamSpec* ps) {
	TrfPersona* persona = NULL;
	GObject* _tmp0_ = NULL;
	TrfPersona* _tmp1_ = NULL;
	FolksStructuredName* _tmp2_ = NULL;
	FolksStructuredName* _tmp3_ = NULL;
#line 363 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
	g_return_if_fail (self != NULL);
#line 363 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
	g_return_if_fail (persona_p != NULL);
#line 363 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
	g_return_if_fail (ps != NULL);
#line 365 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
	_tmp0_ = persona_p;
#line 365 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
	_tmp1_ = _g_object_ref0 (G_TYPE_CHECK_INSTANCE_CAST (_tmp0_, TRF_TYPE_PERSONA, TrfPersona));
#line 365 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
	persona = _tmp1_;
#line 366 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
	_tmp2_ = folks_name_details_get_structured_name ((FolksNameDetails*) persona);
#line 366 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
	_tmp3_ = _tmp2_;
#line 366 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
	_add_persona_tests_check_sname (self, _tmp3_);
#line 367 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
	_add_persona_tests_exit_if_all_properties_found (self);
#line 363 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
	_g_object_unref0 (persona);
#line 2804 "add-persona.c"
}


static void _add_persona_tests_notify_pstore_cb (AddPersonaTests* self, GObject* _pstore, GParamSpec* ps) {
#line 370 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
	g_return_if_fail (self != NULL);
#line 370 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
	g_return_if_fail (_pstore != NULL);
#line 370 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
	g_return_if_fail (ps != NULL);
#line 372 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
	_add_persona_tests_try_to_add (self);
#line 2817 "add-persona.c"
}


static void _add_persona_tests_try_to_add (AddPersonaTests* self) {
	gboolean _tmp0_ = FALSE;
	TrfPersonaStore* _tmp1_ = NULL;
	gboolean _tmp2_ = FALSE;
	gboolean _tmp3_ = FALSE;
#line 375 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
	g_return_if_fail (self != NULL);
#line 377 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
	_tmp1_ = self->priv->_pstore;
#line 377 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
	_tmp2_ = folks_persona_store_get_is_prepared ((FolksPersonaStore*) _tmp1_);
#line 377 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
	_tmp3_ = _tmp2_;
#line 377 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
	if (_tmp3_) {
#line 2836 "add-persona.c"
		gboolean _tmp4_ = FALSE;
#line 377 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
		_tmp4_ = self->priv->_added_persona;
#line 377 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
		_tmp0_ = _tmp4_ == FALSE;
#line 2842 "add-persona.c"
	} else {
#line 377 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
		_tmp0_ = FALSE;
#line 2846 "add-persona.c"
	}
#line 377 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
	if (_tmp0_) {
#line 379 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
		self->priv->_added_persona = TRUE;
#line 380 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
		_add_persona_tests_add_persona (self, NULL, NULL);
#line 2854 "add-persona.c"
	}
}


static void ___lambda4_ (AddPersonaTests* self, GObject* obj, GAsyncResult* _result_) {
	GAsyncResult* _tmp0_ = NULL;
	gboolean _tmp1_ = FALSE;
#line 480 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
	g_return_if_fail (_result_ != NULL);
#line 482 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
	_tmp0_ = _result_;
#line 482 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
	_tmp1_ = folks_test_utils_loadable_icons_content_equal_finish (_tmp0_);
#line 482 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
	if (_tmp1_) {
#line 2870 "add-persona.c"
		GHashTable* _tmp2_ = NULL;
		gchar* _tmp3_ = NULL;
#line 483 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
		_tmp2_ = self->priv->_properties_found;
#line 483 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
		_tmp3_ = g_strdup ("avatar");
#line 483 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
		g_hash_table_replace (_tmp2_, _tmp3_, (gpointer) ((gintptr) TRUE));
#line 2879 "add-persona.c"
	}
#line 485 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
	_add_persona_tests_exit_if_all_properties_found (self);
#line 2883 "add-persona.c"
}


static void ____lambda4__gasync_ready_callback (GObject* source_object, GAsyncResult* res, gpointer self) {
#line 478 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
	___lambda4_ ((AddPersonaTests*) self, source_object, res);
#line 478 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
	g_object_unref (self);
#line 2892 "add-persona.c"
}


static void _add_persona_tests_check_properties (AddPersonaTests* self, FolksIndividual* i) {
	FolksIndividual* _tmp0_ = NULL;
	const gchar* _tmp1_ = NULL;
	const gchar* _tmp2_ = NULL;
	const gchar* _tmp3_ = NULL;
	FolksIndividual* _tmp6_ = NULL;
	const gchar* _tmp7_ = NULL;
	const gchar* _tmp8_ = NULL;
	const gchar* _tmp9_ = NULL;
	FolksIndividual* _tmp12_ = NULL;
	gboolean _tmp13_ = FALSE;
	gboolean _tmp14_ = FALSE;
	FolksIndividual* _tmp17_ = NULL;
	FolksStructuredName* _tmp18_ = NULL;
	FolksStructuredName* _tmp19_ = NULL;
	gboolean _tmp23_ = FALSE;
	FolksIndividual* _tmp24_ = NULL;
	GDateTime* _tmp25_ = NULL;
	GDateTime* _tmp26_ = NULL;
	FolksIndividual* _tmp34_ = NULL;
	FolksGender _tmp35_ = 0;
	FolksGender _tmp36_ = 0;
	FolksIndividual* _tmp190_ = NULL;
	GLoadableIcon* _tmp191_ = NULL;
	GLoadableIcon* _tmp192_ = NULL;
#line 384 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
	g_return_if_fail (self != NULL);
#line 384 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
	g_return_if_fail (i != NULL);
#line 386 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
	_tmp0_ = i;
#line 386 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
	_tmp1_ = folks_name_details_get_full_name ((FolksNameDetails*) _tmp0_);
#line 386 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
	_tmp2_ = _tmp1_;
#line 386 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
	_tmp3_ = self->priv->_persona_fullname;
#line 386 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
	if (g_strcmp0 (_tmp2_, _tmp3_) == 0) {
#line 2935 "add-persona.c"
		GHashTable* _tmp4_ = NULL;
		gchar* _tmp5_ = NULL;
#line 387 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
		_tmp4_ = self->priv->_properties_found;
#line 387 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
		_tmp5_ = g_strdup ("full_name");
#line 387 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
		g_hash_table_replace (_tmp4_, _tmp5_, (gpointer) ((gintptr) TRUE));
#line 2944 "add-persona.c"
	}
#line 389 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
	_tmp6_ = i;
#line 389 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
	_tmp7_ = folks_name_details_get_nickname ((FolksNameDetails*) _tmp6_);
#line 389 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
	_tmp8_ = _tmp7_;
#line 389 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
	_tmp9_ = self->priv->_persona_nickname;
#line 389 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
	if (g_strcmp0 (_tmp8_, _tmp9_) == 0) {
#line 2956 "add-persona.c"
		GHashTable* _tmp10_ = NULL;
		gchar* _tmp11_ = NULL;
#line 390 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
		_tmp10_ = self->priv->_properties_found;
#line 390 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
		_tmp11_ = g_strdup ("nickname");
#line 390 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
		g_hash_table_replace (_tmp10_, _tmp11_, (gpointer) ((gintptr) TRUE));
#line 2965 "add-persona.c"
	}
#line 392 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
	_tmp12_ = i;
#line 392 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
	_tmp13_ = folks_favourite_details_get_is_favourite ((FolksFavouriteDetails*) _tmp12_);
#line 392 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
	_tmp14_ = _tmp13_;
#line 392 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
	if (_tmp14_) {
#line 2975 "add-persona.c"
		GHashTable* _tmp15_ = NULL;
		gchar* _tmp16_ = NULL;
#line 393 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
		_tmp15_ = self->priv->_properties_found;
#line 393 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
		_tmp16_ = g_strdup ("is_favourite");
#line 393 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
		g_hash_table_replace (_tmp15_, _tmp16_, (gpointer) ((gintptr) TRUE));
#line 2984 "add-persona.c"
	}
#line 395 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
	_tmp17_ = i;
#line 395 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
	_tmp18_ = folks_name_details_get_structured_name ((FolksNameDetails*) _tmp17_);
#line 395 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
	_tmp19_ = _tmp18_;
#line 395 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
	if (_tmp19_ != NULL) {
#line 2994 "add-persona.c"
		FolksIndividual* _tmp20_ = NULL;
		FolksStructuredName* _tmp21_ = NULL;
		FolksStructuredName* _tmp22_ = NULL;
#line 397 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
		_tmp20_ = i;
#line 397 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
		_tmp21_ = folks_name_details_get_structured_name ((FolksNameDetails*) _tmp20_);
#line 397 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
		_tmp22_ = _tmp21_;
#line 397 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
		_add_persona_tests_check_sname (self, _tmp22_);
#line 3006 "add-persona.c"
	}
#line 400 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
	_tmp24_ = i;
#line 400 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
	_tmp25_ = folks_birthday_details_get_birthday ((FolksBirthdayDetails*) _tmp24_);
#line 400 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
	_tmp26_ = _tmp25_;
#line 400 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
	if (_tmp26_ != NULL) {
#line 3016 "add-persona.c"
		FolksIndividual* _tmp27_ = NULL;
		GDateTime* _tmp28_ = NULL;
		GDateTime* _tmp29_ = NULL;
		GDateTime* _tmp30_ = NULL;
		gint _tmp31_ = 0;
#line 401 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
		_tmp27_ = i;
#line 401 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
		_tmp28_ = folks_birthday_details_get_birthday ((FolksBirthdayDetails*) _tmp27_);
#line 401 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
		_tmp29_ = _tmp28_;
#line 401 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
		_tmp30_ = self->priv->_bday;
#line 401 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
		_tmp31_ = g_date_time_compare (_tmp29_, _tmp30_);
#line 401 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
		_tmp23_ = _tmp31_ == 0;
#line 3034 "add-persona.c"
	} else {
#line 400 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
		_tmp23_ = FALSE;
#line 3038 "add-persona.c"
	}
#line 400 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
	if (_tmp23_) {
#line 3042 "add-persona.c"
		GHashTable* _tmp32_ = NULL;
		gchar* _tmp33_ = NULL;
#line 402 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
		_tmp32_ = self->priv->_properties_found;
#line 402 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
		_tmp33_ = g_strdup ("birthday");
#line 402 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
		g_hash_table_replace (_tmp32_, _tmp33_, (gpointer) ((gintptr) TRUE));
#line 3051 "add-persona.c"
	}
#line 404 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
	_tmp34_ = i;
#line 404 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
	_tmp35_ = folks_gender_details_get_gender ((FolksGenderDetails*) _tmp34_);
#line 404 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
	_tmp36_ = _tmp35_;
#line 404 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
	if (_tmp36_ == FOLKS_GENDER_MALE) {
#line 3061 "add-persona.c"
		GHashTable* _tmp37_ = NULL;
		gchar* _tmp38_ = NULL;
#line 405 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
		_tmp37_ = self->priv->_properties_found;
#line 405 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
		_tmp38_ = g_strdup ("gender");
#line 405 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
		g_hash_table_replace (_tmp37_, _tmp38_, (gpointer) ((gintptr) TRUE));
#line 3070 "add-persona.c"
	}
	{
		GeeIterator* _e_it = NULL;
		FolksIndividual* _tmp39_ = NULL;
		GeeSet* _tmp40_ = NULL;
		GeeSet* _tmp41_ = NULL;
		GeeIterator* _tmp42_ = NULL;
#line 407 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
		_tmp39_ = i;
#line 407 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
		_tmp40_ = folks_email_details_get_email_addresses ((FolksEmailDetails*) _tmp39_);
#line 407 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
		_tmp41_ = _tmp40_;
#line 407 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
		_tmp42_ = gee_iterable_iterator ((GeeIterable*) _tmp41_);
#line 407 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
		_e_it = _tmp42_;
#line 407 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
		while (TRUE) {
#line 3090 "add-persona.c"
			GeeIterator* _tmp43_ = NULL;
			gboolean _tmp44_ = FALSE;
			FolksEmailFieldDetails* e = NULL;
			GeeIterator* _tmp45_ = NULL;
			gpointer _tmp46_ = NULL;
			FolksEmailFieldDetails* _tmp47_ = NULL;
			gconstpointer _tmp48_ = NULL;
			const gchar* _tmp49_ = NULL;
			const gchar* _tmp50_ = NULL;
#line 407 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
			_tmp43_ = _e_it;
#line 407 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
			_tmp44_ = gee_iterator_next (_tmp43_);
#line 407 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
			if (!_tmp44_) {
#line 407 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
				break;
#line 3108 "add-persona.c"
			}
#line 407 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
			_tmp45_ = _e_it;
#line 407 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
			_tmp46_ = gee_iterator_get (_tmp45_);
#line 407 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
			e = (FolksEmailFieldDetails*) _tmp46_;
#line 409 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
			_tmp47_ = e;
#line 409 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
			_tmp48_ = folks_abstract_field_details_get_value ((FolksAbstractFieldDetails*) _tmp47_);
#line 409 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
			_tmp49_ = _tmp48_;
#line 409 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
			_tmp50_ = self->priv->_email_1;
#line 409 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
			if (g_strcmp0 ((const gchar*) _tmp49_, _tmp50_) == 0) {
#line 3126 "add-persona.c"
				GHashTable* _tmp51_ = NULL;
				gchar* _tmp52_ = NULL;
#line 411 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
				_tmp51_ = self->priv->_properties_found;
#line 411 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
				_tmp52_ = g_strdup ("email-1");
#line 411 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
				g_hash_table_replace (_tmp51_, _tmp52_, (gpointer) ((gintptr) TRUE));
#line 3135 "add-persona.c"
			} else {
				FolksEmailFieldDetails* _tmp53_ = NULL;
				gconstpointer _tmp54_ = NULL;
				const gchar* _tmp55_ = NULL;
				const gchar* _tmp56_ = NULL;
#line 413 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
				_tmp53_ = e;
#line 413 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
				_tmp54_ = folks_abstract_field_details_get_value ((FolksAbstractFieldDetails*) _tmp53_);
#line 413 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
				_tmp55_ = _tmp54_;
#line 413 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
				_tmp56_ = self->priv->_email_2;
#line 413 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
				if (g_strcmp0 ((const gchar*) _tmp55_, _tmp56_) == 0) {
#line 3151 "add-persona.c"
					GHashTable* _tmp57_ = NULL;
					gchar* _tmp58_ = NULL;
#line 415 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
					_tmp57_ = self->priv->_properties_found;
#line 415 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
					_tmp58_ = g_strdup ("email-2");
#line 415 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
					g_hash_table_replace (_tmp57_, _tmp58_, (gpointer) ((gintptr) TRUE));
#line 3160 "add-persona.c"
				}
			}
#line 407 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
			_g_object_unref0 (e);
#line 3165 "add-persona.c"
		}
#line 407 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
		_g_object_unref0 (_e_it);
#line 3169 "add-persona.c"
	}
	{
		GeeIterator* _proto_it = NULL;
		FolksIndividual* _tmp59_ = NULL;
		GeeMultiMap* _tmp60_ = NULL;
		GeeMultiMap* _tmp61_ = NULL;
		GeeSet* _tmp62_ = NULL;
		GeeSet* _tmp63_ = NULL;
		GeeIterator* _tmp64_ = NULL;
		GeeIterator* _tmp65_ = NULL;
#line 419 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
		_tmp59_ = i;
#line 419 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
		_tmp60_ = folks_im_details_get_im_addresses ((FolksImDetails*) _tmp59_);
#line 419 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
		_tmp61_ = _tmp60_;
#line 419 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
		_tmp62_ = gee_multi_map_get_keys (_tmp61_);
#line 419 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
		_tmp63_ = _tmp62_;
#line 419 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
		_tmp64_ = gee_iterable_iterator ((GeeIterable*) _tmp63_);
#line 419 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
		_tmp65_ = _tmp64_;
#line 419 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
		_g_object_unref0 (_tmp63_);
#line 419 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
		_proto_it = _tmp65_;
#line 419 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
		while (TRUE) {
#line 3200 "add-persona.c"
			GeeIterator* _tmp66_ = NULL;
			gboolean _tmp67_ = FALSE;
			gchar* proto = NULL;
			GeeIterator* _tmp68_ = NULL;
			gpointer _tmp69_ = NULL;
			GeeCollection* addrs = NULL;
			FolksIndividual* _tmp70_ = NULL;
			GeeMultiMap* _tmp71_ = NULL;
			GeeMultiMap* _tmp72_ = NULL;
			const gchar* _tmp73_ = NULL;
			GeeCollection* _tmp74_ = NULL;
#line 419 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
			_tmp66_ = _proto_it;
#line 419 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
			_tmp67_ = gee_iterator_next (_tmp66_);
#line 419 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
			if (!_tmp67_) {
#line 419 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
				break;
#line 3220 "add-persona.c"
			}
#line 419 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
			_tmp68_ = _proto_it;
#line 419 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
			_tmp69_ = gee_iterator_get (_tmp68_);
#line 419 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
			proto = (gchar*) _tmp69_;
#line 421 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
			_tmp70_ = i;
#line 421 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
			_tmp71_ = folks_im_details_get_im_addresses ((FolksImDetails*) _tmp70_);
#line 421 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
			_tmp72_ = _tmp71_;
#line 421 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
			_tmp73_ = proto;
#line 421 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
			_tmp74_ = gee_multi_map_get (_tmp72_, _tmp73_);
#line 421 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
			addrs = _tmp74_;
#line 3240 "add-persona.c"
			{
				GeeIterator* _a_it = NULL;
				GeeCollection* _tmp75_ = NULL;
				GeeIterator* _tmp76_ = NULL;
#line 422 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
				_tmp75_ = addrs;
#line 422 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
				_tmp76_ = gee_iterable_iterator ((GeeIterable*) _tmp75_);
#line 422 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
				_a_it = _tmp76_;
#line 422 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
				while (TRUE) {
#line 3253 "add-persona.c"
					GeeIterator* _tmp77_ = NULL;
					gboolean _tmp78_ = FALSE;
					FolksImFieldDetails* a = NULL;
					GeeIterator* _tmp79_ = NULL;
					gpointer _tmp80_ = NULL;
					FolksImFieldDetails* _tmp81_ = NULL;
					gconstpointer _tmp82_ = NULL;
					const gchar* _tmp83_ = NULL;
					const gchar* _tmp84_ = NULL;
#line 422 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
					_tmp77_ = _a_it;
#line 422 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
					_tmp78_ = gee_iterator_next (_tmp77_);
#line 422 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
					if (!_tmp78_) {
#line 422 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
						break;
#line 3271 "add-persona.c"
					}
#line 422 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
					_tmp79_ = _a_it;
#line 422 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
					_tmp80_ = gee_iterator_get (_tmp79_);
#line 422 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
					a = (FolksImFieldDetails*) _tmp80_;
#line 424 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
					_tmp81_ = a;
#line 424 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
					_tmp82_ = folks_abstract_field_details_get_value ((FolksAbstractFieldDetails*) _tmp81_);
#line 424 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
					_tmp83_ = _tmp82_;
#line 424 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
					_tmp84_ = self->priv->_im_addr_1;
#line 424 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
					if (g_strcmp0 ((const gchar*) _tmp83_, _tmp84_) == 0) {
#line 3289 "add-persona.c"
						GHashTable* _tmp85_ = NULL;
						gchar* _tmp86_ = NULL;
#line 425 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
						_tmp85_ = self->priv->_properties_found;
#line 425 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
						_tmp86_ = g_strdup ("im-addr-1");
#line 425 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
						g_hash_table_replace (_tmp85_, _tmp86_, (gpointer) ((gintptr) TRUE));
#line 3298 "add-persona.c"
					} else {
						FolksImFieldDetails* _tmp87_ = NULL;
						gconstpointer _tmp88_ = NULL;
						const gchar* _tmp89_ = NULL;
						const gchar* _tmp90_ = NULL;
#line 426 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
						_tmp87_ = a;
#line 426 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
						_tmp88_ = folks_abstract_field_details_get_value ((FolksAbstractFieldDetails*) _tmp87_);
#line 426 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
						_tmp89_ = _tmp88_;
#line 426 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
						_tmp90_ = self->priv->_im_addr_2;
#line 426 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
						if (g_strcmp0 ((const gchar*) _tmp89_, _tmp90_) == 0) {
#line 3314 "add-persona.c"
							GHashTable* _tmp91_ = NULL;
							gchar* _tmp92_ = NULL;
#line 427 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
							_tmp91_ = self->priv->_properties_found;
#line 427 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
							_tmp92_ = g_strdup ("im-addr-2");
#line 427 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
							g_hash_table_replace (_tmp91_, _tmp92_, (gpointer) ((gintptr) TRUE));
#line 3323 "add-persona.c"
						}
					}
#line 422 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
					_g_object_unref0 (a);
#line 3328 "add-persona.c"
				}
#line 422 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
				_g_object_unref0 (_a_it);
#line 3332 "add-persona.c"
			}
#line 419 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
			_g_object_unref0 (addrs);
#line 419 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
			_g_free0 (proto);
#line 3338 "add-persona.c"
		}
#line 419 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
		_g_object_unref0 (_proto_it);
#line 3342 "add-persona.c"
	}
	{
		GeeIterator* _n_it = NULL;
		FolksIndividual* _tmp93_ = NULL;
		GeeSet* _tmp94_ = NULL;
		GeeSet* _tmp95_ = NULL;
		GeeIterator* _tmp96_ = NULL;
#line 431 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
		_tmp93_ = i;
#line 431 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
		_tmp94_ = folks_note_details_get_notes ((FolksNoteDetails*) _tmp93_);
#line 431 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
		_tmp95_ = _tmp94_;
#line 431 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
		_tmp96_ = gee_iterable_iterator ((GeeIterable*) _tmp95_);
#line 431 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
		_n_it = _tmp96_;
#line 431 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
		while (TRUE) {
#line 3362 "add-persona.c"
			GeeIterator* _tmp97_ = NULL;
			gboolean _tmp98_ = FALSE;
			FolksNoteFieldDetails* n = NULL;
			GeeIterator* _tmp99_ = NULL;
			gpointer _tmp100_ = NULL;
			FolksNoteFieldDetails* _tmp101_ = NULL;
			const gchar* _tmp102_ = NULL;
			FolksNoteFieldDetails* _tmp103_ = NULL;
			FolksNoteFieldDetails* _tmp104_ = NULL;
			gboolean _tmp105_ = FALSE;
			gboolean _tmp106_ = FALSE;
#line 431 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
			_tmp97_ = _n_it;
#line 431 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
			_tmp98_ = gee_iterator_next (_tmp97_);
#line 431 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
			if (!_tmp98_) {
#line 431 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
				break;
#line 3382 "add-persona.c"
			}
#line 431 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
			_tmp99_ = _n_it;
#line 431 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
			_tmp100_ = gee_iterator_get (_tmp99_);
#line 431 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
			n = (FolksNoteFieldDetails*) _tmp100_;
#line 433 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
			_tmp101_ = n;
#line 433 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
			_tmp102_ = self->priv->_note_1;
#line 433 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
			_tmp103_ = folks_note_field_details_new (_tmp102_, NULL, NULL);
#line 433 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
			_tmp104_ = _tmp103_;
#line 433 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
			_tmp105_ = folks_abstract_field_details_equal ((FolksAbstractFieldDetails*) _tmp101_, (FolksAbstractFieldDetails*) _tmp104_);
#line 433 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
			_tmp106_ = _tmp105_;
#line 433 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
			_g_object_unref0 (_tmp104_);
#line 433 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
			if (_tmp106_) {
#line 3406 "add-persona.c"
				GHashTable* _tmp107_ = NULL;
				gchar* _tmp108_ = NULL;
#line 435 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
				_tmp107_ = self->priv->_properties_found;
#line 435 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
				_tmp108_ = g_strdup ("note-1");
#line 435 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
				g_hash_table_replace (_tmp107_, _tmp108_, (gpointer) ((gintptr) TRUE));
#line 3415 "add-persona.c"
			}
#line 431 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
			_g_object_unref0 (n);
#line 3419 "add-persona.c"
		}
#line 431 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
		_g_object_unref0 (_n_it);
#line 3423 "add-persona.c"
	}
	{
		GeeIterator* _phone_fd_it = NULL;
		FolksIndividual* _tmp109_ = NULL;
		GeeSet* _tmp110_ = NULL;
		GeeSet* _tmp111_ = NULL;
		GeeIterator* _tmp112_ = NULL;
#line 439 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
		_tmp109_ = i;
#line 439 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
		_tmp110_ = folks_phone_details_get_phone_numbers ((FolksPhoneDetails*) _tmp109_);
#line 439 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
		_tmp111_ = _tmp110_;
#line 439 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
		_tmp112_ = gee_iterable_iterator ((GeeIterable*) _tmp111_);
#line 439 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
		_phone_fd_it = _tmp112_;
#line 439 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
		while (TRUE) {
#line 3443 "add-persona.c"
			GeeIterator* _tmp113_ = NULL;
			gboolean _tmp114_ = FALSE;
			FolksPhoneFieldDetails* phone_fd = NULL;
			GeeIterator* _tmp115_ = NULL;
			gpointer _tmp116_ = NULL;
			FolksPhoneFieldDetails* _tmp117_ = NULL;
			const gchar* _tmp118_ = NULL;
			FolksPhoneFieldDetails* _tmp119_ = NULL;
			FolksPhoneFieldDetails* _tmp120_ = NULL;
			gboolean _tmp121_ = FALSE;
			gboolean _tmp122_ = FALSE;
#line 439 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
			_tmp113_ = _phone_fd_it;
#line 439 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
			_tmp114_ = gee_iterator_next (_tmp113_);
#line 439 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
			if (!_tmp114_) {
#line 439 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
				break;
#line 3463 "add-persona.c"
			}
#line 439 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
			_tmp115_ = _phone_fd_it;
#line 439 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
			_tmp116_ = gee_iterator_get (_tmp115_);
#line 439 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
			phone_fd = (FolksPhoneFieldDetails*) _tmp116_;
#line 441 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
			_tmp117_ = phone_fd;
#line 441 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
			_tmp118_ = self->priv->_phone_1;
#line 441 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
			_tmp119_ = folks_phone_field_details_new (_tmp118_, NULL);
#line 441 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
			_tmp120_ = _tmp119_;
#line 441 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
			_tmp121_ = folks_abstract_field_details_equal ((FolksAbstractFieldDetails*) _tmp117_, (FolksAbstractFieldDetails*) _tmp120_);
#line 441 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
			_tmp122_ = _tmp121_;
#line 441 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
			_g_object_unref0 (_tmp120_);
#line 441 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
			if (_tmp122_) {
#line 3487 "add-persona.c"
				GHashTable* _tmp123_ = NULL;
				gchar* _tmp124_ = NULL;
#line 443 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
				_tmp123_ = self->priv->_properties_found;
#line 443 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
				_tmp124_ = g_strdup ("phone-1");
#line 443 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
				g_hash_table_replace (_tmp123_, _tmp124_, (gpointer) ((gintptr) TRUE));
#line 3496 "add-persona.c"
			} else {
				FolksPhoneFieldDetails* _tmp125_ = NULL;
				const gchar* _tmp126_ = NULL;
				FolksPhoneFieldDetails* _tmp127_ = NULL;
				FolksPhoneFieldDetails* _tmp128_ = NULL;
				gboolean _tmp129_ = FALSE;
				gboolean _tmp130_ = FALSE;
#line 445 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
				_tmp125_ = phone_fd;
#line 445 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
				_tmp126_ = self->priv->_phone_2;
#line 445 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
				_tmp127_ = folks_phone_field_details_new (_tmp126_, NULL);
#line 445 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
				_tmp128_ = _tmp127_;
#line 445 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
				_tmp129_ = folks_abstract_field_details_equal ((FolksAbstractFieldDetails*) _tmp125_, (FolksAbstractFieldDetails*) _tmp128_);
#line 445 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
				_tmp130_ = _tmp129_;
#line 445 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
				_g_object_unref0 (_tmp128_);
#line 445 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
				if (_tmp130_) {
#line 3520 "add-persona.c"
					GHashTable* _tmp131_ = NULL;
					gchar* _tmp132_ = NULL;
#line 447 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
					_tmp131_ = self->priv->_properties_found;
#line 447 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
					_tmp132_ = g_strdup ("phone-2");
#line 447 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
					g_hash_table_replace (_tmp131_, _tmp132_, (gpointer) ((gintptr) TRUE));
#line 3529 "add-persona.c"
				}
			}
#line 439 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
			_g_object_unref0 (phone_fd);
#line 3534 "add-persona.c"
		}
#line 439 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
		_g_object_unref0 (_phone_fd_it);
#line 3538 "add-persona.c"
	}
	{
		GeeIterator* _role_fd_it = NULL;
		FolksIndividual* _tmp133_ = NULL;
		GeeSet* _tmp134_ = NULL;
		GeeSet* _tmp135_ = NULL;
		GeeIterator* _tmp136_ = NULL;
#line 451 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
		_tmp133_ = i;
#line 451 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
		_tmp134_ = folks_role_details_get_roles ((FolksRoleDetails*) _tmp133_);
#line 451 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
		_tmp135_ = _tmp134_;
#line 451 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
		_tmp136_ = gee_iterable_iterator ((GeeIterable*) _tmp135_);
#line 451 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
		_role_fd_it = _tmp136_;
#line 451 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
		while (TRUE) {
#line 3558 "add-persona.c"
			GeeIterator* _tmp137_ = NULL;
			gboolean _tmp138_ = FALSE;
			FolksRoleFieldDetails* role_fd = NULL;
			GeeIterator* _tmp139_ = NULL;
			gpointer _tmp140_ = NULL;
			FolksRole* role_expected = NULL;
			const gchar* _tmp141_ = NULL;
			const gchar* _tmp142_ = NULL;
			FolksRole* _tmp143_ = NULL;
			FolksRole* _tmp144_ = NULL;
			const gchar* _tmp145_ = NULL;
			FolksRoleFieldDetails* role_fd_expected = NULL;
			FolksRole* _tmp146_ = NULL;
			FolksRoleFieldDetails* _tmp147_ = NULL;
			FolksRoleFieldDetails* _tmp148_ = NULL;
			FolksRoleFieldDetails* _tmp149_ = NULL;
			gboolean _tmp150_ = FALSE;
#line 451 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
			_tmp137_ = _role_fd_it;
#line 451 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
			_tmp138_ = gee_iterator_next (_tmp137_);
#line 451 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
			if (!_tmp138_) {
#line 451 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
				break;
#line 3584 "add-persona.c"
			}
#line 451 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
			_tmp139_ = _role_fd_it;
#line 451 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
			_tmp140_ = gee_iterator_get (_tmp139_);
#line 451 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
			role_fd = (FolksRoleFieldDetails*) _tmp140_;
#line 453 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
			_tmp141_ = self->priv->_title_1;
#line 453 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
			_tmp142_ = self->priv->_organisation_1;
#line 453 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
			_tmp143_ = folks_role_new (_tmp141_, _tmp142_, NULL);
#line 453 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
			role_expected = _tmp143_;
#line 454 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
			_tmp144_ = role_expected;
#line 454 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
			_tmp145_ = self->priv->_role_1;
#line 454 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
			folks_role_set_role (_tmp144_, _tmp145_);
#line 455 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
			_tmp146_ = role_expected;
#line 455 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
			_tmp147_ = folks_role_field_details_new (_tmp146_, NULL);
#line 455 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
			role_fd_expected = _tmp147_;
#line 456 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
			_tmp148_ = role_fd;
#line 456 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
			_tmp149_ = role_fd_expected;
#line 456 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
			_tmp150_ = folks_abstract_field_details_equal ((FolksAbstractFieldDetails*) _tmp148_, (FolksAbstractFieldDetails*) _tmp149_);
#line 456 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
			if (_tmp150_) {
#line 3620 "add-persona.c"
				GHashTable* _tmp151_ = NULL;
				gchar* _tmp152_ = NULL;
#line 457 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
				_tmp151_ = self->priv->_properties_found;
#line 457 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
				_tmp152_ = g_strdup ("role-1");
#line 457 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
				g_hash_table_replace (_tmp151_, _tmp152_, (gpointer) ((gintptr) TRUE));
#line 3629 "add-persona.c"
			}
#line 451 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
			_g_object_unref0 (role_fd_expected);
#line 451 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
			_g_object_unref0 (role_expected);
#line 451 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
			_g_object_unref0 (role_fd);
#line 3637 "add-persona.c"
		}
#line 451 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
		_g_object_unref0 (_role_fd_it);
#line 3641 "add-persona.c"
	}
	{
		GeeIterator* _pafd_it = NULL;
		FolksIndividual* _tmp153_ = NULL;
		GeeSet* _tmp154_ = NULL;
		GeeSet* _tmp155_ = NULL;
		GeeIterator* _tmp156_ = NULL;
#line 460 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
		_tmp153_ = i;
#line 460 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
		_tmp154_ = folks_postal_address_details_get_postal_addresses ((FolksPostalAddressDetails*) _tmp153_);
#line 460 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
		_tmp155_ = _tmp154_;
#line 460 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
		_tmp156_ = gee_iterable_iterator ((GeeIterable*) _tmp155_);
#line 460 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
		_pafd_it = _tmp156_;
#line 460 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
		while (TRUE) {
#line 3661 "add-persona.c"
			GeeIterator* _tmp157_ = NULL;
			gboolean _tmp158_ = FALSE;
			FolksPostalAddressFieldDetails* pafd = NULL;
			GeeIterator* _tmp159_ = NULL;
			gpointer _tmp160_ = NULL;
			FolksPostalAddressFieldDetails* _tmp161_ = NULL;
			FolksPostalAddressFieldDetails* _tmp162_ = NULL;
			const gchar* _tmp163_ = NULL;
			const gchar* _tmp164_ = NULL;
			FolksPostalAddressFieldDetails* _tmp165_ = NULL;
			FolksPostalAddressFieldDetails* _tmp166_ = NULL;
			gboolean _tmp167_ = FALSE;
#line 460 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
			_tmp157_ = _pafd_it;
#line 460 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
			_tmp158_ = gee_iterator_next (_tmp157_);
#line 460 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
			if (!_tmp158_) {
#line 460 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
				break;
#line 3682 "add-persona.c"
			}
#line 460 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
			_tmp159_ = _pafd_it;
#line 460 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
			_tmp160_ = gee_iterator_get (_tmp159_);
#line 460 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
			pafd = (FolksPostalAddressFieldDetails*) _tmp160_;
#line 462 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
			_tmp161_ = self->priv->_postal_address_fd;
#line 462 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
			_tmp162_ = pafd;
#line 462 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
			_tmp163_ = folks_abstract_field_details_get_id ((FolksAbstractFieldDetails*) _tmp162_);
#line 462 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
			_tmp164_ = _tmp163_;
#line 462 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
			folks_abstract_field_details_set_id ((FolksAbstractFieldDetails*) _tmp161_, _tmp164_);
#line 463 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
			_tmp165_ = pafd;
#line 463 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
			_tmp166_ = self->priv->_postal_address_fd;
#line 463 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
			_tmp167_ = folks_abstract_field_details_equal ((FolksAbstractFieldDetails*) _tmp165_, (FolksAbstractFieldDetails*) _tmp166_);
#line 463 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
			if (_tmp167_) {
#line 3708 "add-persona.c"
				GHashTable* _tmp168_ = NULL;
				gchar* _tmp169_ = NULL;
#line 464 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
				_tmp168_ = self->priv->_properties_found;
#line 464 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
				_tmp169_ = g_strdup ("postal-address-1");
#line 464 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
				g_hash_table_replace (_tmp168_, _tmp169_, (gpointer) ((gintptr) TRUE));
#line 3717 "add-persona.c"
			}
#line 460 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
			_g_object_unref0 (pafd);
#line 3721 "add-persona.c"
		}
#line 460 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
		_g_object_unref0 (_pafd_it);
#line 3725 "add-persona.c"
	}
	{
		GeeIterator* _u_it = NULL;
		FolksIndividual* _tmp170_ = NULL;
		GeeSet* _tmp171_ = NULL;
		GeeSet* _tmp172_ = NULL;
		GeeIterator* _tmp173_ = NULL;
#line 467 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
		_tmp170_ = i;
#line 467 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
		_tmp171_ = folks_url_details_get_urls ((FolksUrlDetails*) _tmp170_);
#line 467 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
		_tmp172_ = _tmp171_;
#line 467 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
		_tmp173_ = gee_iterable_iterator ((GeeIterable*) _tmp172_);
#line 467 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
		_u_it = _tmp173_;
#line 467 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
		while (TRUE) {
#line 3745 "add-persona.c"
			GeeIterator* _tmp174_ = NULL;
			gboolean _tmp175_ = FALSE;
			FolksUrlFieldDetails* u = NULL;
			GeeIterator* _tmp176_ = NULL;
			gpointer _tmp177_ = NULL;
			FolksUrlFieldDetails* _tmp178_ = NULL;
			gconstpointer _tmp179_ = NULL;
			const gchar* _tmp180_ = NULL;
			const gchar* _tmp181_ = NULL;
			FolksUrlFieldDetails* _tmp184_ = NULL;
			gconstpointer _tmp185_ = NULL;
			const gchar* _tmp186_ = NULL;
			const gchar* _tmp187_ = NULL;
#line 467 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
			_tmp174_ = _u_it;
#line 467 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
			_tmp175_ = gee_iterator_next (_tmp174_);
#line 467 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
			if (!_tmp175_) {
#line 467 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
				break;
#line 3767 "add-persona.c"
			}
#line 467 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
			_tmp176_ = _u_it;
#line 467 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
			_tmp177_ = gee_iterator_get (_tmp176_);
#line 467 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
			u = (FolksUrlFieldDetails*) _tmp177_;
#line 469 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
			_tmp178_ = u;
#line 469 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
			_tmp179_ = folks_abstract_field_details_get_value ((FolksAbstractFieldDetails*) _tmp178_);
#line 469 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
			_tmp180_ = _tmp179_;
#line 469 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
			_tmp181_ = self->priv->_url_1;
#line 469 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
			if (g_strcmp0 ((const gchar*) _tmp180_, _tmp181_) == 0) {
#line 3785 "add-persona.c"
				GHashTable* _tmp182_ = NULL;
				gchar* _tmp183_ = NULL;
#line 470 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
				_tmp182_ = self->priv->_properties_found;
#line 470 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
				_tmp183_ = g_strdup ("url-1");
#line 470 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
				g_hash_table_replace (_tmp182_, _tmp183_, (gpointer) ((gintptr) TRUE));
#line 3794 "add-persona.c"
			}
#line 471 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
			_tmp184_ = u;
#line 471 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
			_tmp185_ = folks_abstract_field_details_get_value ((FolksAbstractFieldDetails*) _tmp184_);
#line 471 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
			_tmp186_ = _tmp185_;
#line 471 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
			_tmp187_ = self->priv->_url_2;
#line 471 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
			if (g_strcmp0 ((const gchar*) _tmp186_, _tmp187_) == 0) {
#line 3806 "add-persona.c"
				GHashTable* _tmp188_ = NULL;
				gchar* _tmp189_ = NULL;
#line 472 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
				_tmp188_ = self->priv->_properties_found;
#line 472 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
				_tmp189_ = g_strdup ("url-2");
#line 472 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
				g_hash_table_replace (_tmp188_, _tmp189_, (gpointer) ((gintptr) TRUE));
#line 3815 "add-persona.c"
			}
#line 467 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
			_g_object_unref0 (u);
#line 3819 "add-persona.c"
		}
#line 467 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
		_g_object_unref0 (_u_it);
#line 3823 "add-persona.c"
	}
#line 475 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
	_tmp190_ = i;
#line 475 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
	_tmp191_ = folks_avatar_details_get_avatar ((FolksAvatarDetails*) _tmp190_);
#line 475 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
	_tmp192_ = _tmp191_;
#line 475 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
	if (_tmp192_ != NULL) {
#line 3833 "add-persona.c"
		FolksIndividual* _tmp193_ = NULL;
		GLoadableIcon* _tmp194_ = NULL;
		GLoadableIcon* _tmp195_ = NULL;
		GLoadableIcon* _tmp196_ = NULL;
#line 478 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
		_tmp193_ = i;
#line 478 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
		_tmp194_ = folks_avatar_details_get_avatar ((FolksAvatarDetails*) _tmp193_);
#line 478 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
		_tmp195_ = _tmp194_;
#line 478 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
		_tmp196_ = self->priv->_avatar;
#line 478 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
		folks_test_utils_loadable_icons_content_equal (_tmp195_, _tmp196_, 100, ____lambda4__gasync_ready_callback, g_object_ref (self));
#line 3848 "add-persona.c"
	}
#line 489 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
	_add_persona_tests_exit_if_all_properties_found (self);
#line 3852 "add-persona.c"
}


static void _add_persona_tests_exit_if_all_properties_found (AddPersonaTests* self) {
	GHashTable* _tmp0_ = NULL;
	GList* _tmp1_ = NULL;
	GMainLoop* _tmp6_ = NULL;
#line 492 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
	g_return_if_fail (self != NULL);
#line 494 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
	_tmp0_ = self->priv->_properties_found;
#line 494 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
	_tmp1_ = g_hash_table_get_keys (_tmp0_);
#line 3866 "add-persona.c"
	{
		GList* k_collection = NULL;
		GList* k_it = NULL;
#line 494 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
		k_collection = _tmp1_;
#line 494 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
		for (k_it = k_collection; k_it != NULL; k_it = k_it->next) {
#line 3874 "add-persona.c"
			const gchar* k = NULL;
#line 494 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
			k = (const gchar*) k_it->data;
#line 3878 "add-persona.c"
			{
				gboolean v = FALSE;
				GHashTable* _tmp2_ = NULL;
				const gchar* _tmp3_ = NULL;
				gconstpointer _tmp4_ = NULL;
				gboolean _tmp5_ = FALSE;
#line 496 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
				_tmp2_ = self->priv->_properties_found;
#line 496 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
				_tmp3_ = k;
#line 496 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
				_tmp4_ = g_hash_table_lookup (_tmp2_, _tmp3_);
#line 496 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
				v = (gboolean) ((gintptr) _tmp4_);
#line 497 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
				_tmp5_ = v;
#line 497 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
				if (_tmp5_ == FALSE) {
#line 498 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
					_g_list_free0 (k_collection);
#line 498 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
					return;
#line 3901 "add-persona.c"
				}
			}
		}
#line 494 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
		_g_list_free0 (k_collection);
#line 3907 "add-persona.c"
	}
#line 500 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
	_tmp6_ = self->priv->_main_loop;
#line 500 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
	g_main_loop_quit (_tmp6_);
#line 3913 "add-persona.c"
}


static void _add_persona_tests_check_sname (AddPersonaTests* self, FolksStructuredName* sname) {
	gboolean _tmp0_ = FALSE;
	FolksStructuredName* _tmp1_ = NULL;
	const gchar* _tmp2_ = NULL;
	const gchar* _tmp3_ = NULL;
	const gchar* _tmp4_ = NULL;
#line 503 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
	g_return_if_fail (self != NULL);
#line 503 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
	g_return_if_fail (sname != NULL);
#line 505 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
	_tmp1_ = sname;
#line 505 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
	_tmp2_ = folks_structured_name_get_family_name (_tmp1_);
#line 505 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
	_tmp3_ = _tmp2_;
#line 505 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
	_tmp4_ = self->priv->_family_name;
#line 505 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
	if (g_strcmp0 (_tmp3_, _tmp4_) == 0) {
#line 3937 "add-persona.c"
		FolksStructuredName* _tmp5_ = NULL;
		const gchar* _tmp6_ = NULL;
		const gchar* _tmp7_ = NULL;
		const gchar* _tmp8_ = NULL;
#line 506 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
		_tmp5_ = sname;
#line 506 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
		_tmp6_ = folks_structured_name_get_given_name (_tmp5_);
#line 506 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
		_tmp7_ = _tmp6_;
#line 506 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
		_tmp8_ = self->priv->_given_name;
#line 506 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
		_tmp0_ = g_strcmp0 (_tmp7_, _tmp8_) == 0;
#line 3952 "add-persona.c"
	} else {
#line 505 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
		_tmp0_ = FALSE;
#line 3956 "add-persona.c"
	}
#line 505 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
	if (_tmp0_) {
#line 3960 "add-persona.c"
		GHashTable* _tmp9_ = NULL;
		gchar* _tmp10_ = NULL;
#line 507 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
		_tmp9_ = self->priv->_properties_found;
#line 507 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
		_tmp10_ = g_strdup ("structured_name");
#line 507 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
		g_hash_table_replace (_tmp9_, _tmp10_, (gpointer) ((gintptr) TRUE));
#line 3969 "add-persona.c"
	}
}


static void add_persona_tests_class_init (AddPersonaTestsClass * klass) {
#line 26 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
	add_persona_tests_parent_class = g_type_class_peek_parent (klass);
#line 26 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
	g_type_class_add_private (klass, sizeof (AddPersonaTestsPrivate));
#line 26 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
	G_OBJECT_CLASS (klass)->finalize = add_persona_tests_finalize;
#line 3981 "add-persona.c"
}


static void add_persona_tests_instance_init (AddPersonaTests * self) {
	gchar* _tmp0_ = NULL;
	gchar* _tmp1_ = NULL;
	gchar* _tmp2_ = NULL;
	gchar* _tmp3_ = NULL;
	gchar* _tmp4_ = NULL;
	gchar* _tmp5_ = NULL;
	gchar* _tmp6_ = NULL;
	gchar* _tmp7_ = NULL;
	gchar* _tmp8_ = NULL;
#line 26 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
	self->priv = ADD_PERSONA_TESTS_GET_PRIVATE (self);
#line 50 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
	_tmp0_ = g_strdup ("12345");
#line 50 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
	self->priv->_po_box = _tmp0_;
#line 51 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
	_tmp1_ = g_strdup ("locality");
#line 51 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
	self->priv->_locality = _tmp1_;
#line 52 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
	_tmp2_ = g_strdup ("code");
#line 52 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
	self->priv->_postal_code = _tmp2_;
#line 53 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
	_tmp3_ = g_strdup ("some street");
#line 53 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
	self->priv->_street = _tmp3_;
#line 54 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
	_tmp4_ = g_strdup ("some extension");
#line 54 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
	self->priv->_extension = _tmp4_;
#line 55 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
	_tmp5_ = g_strdup ("some country");
#line 55 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
	self->priv->_country = _tmp5_;
#line 56 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
	_tmp6_ = g_strdup ("some region");
#line 56 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
	self->priv->_region = _tmp6_;
#line 57 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
	_tmp7_ = g_strdup ("http://www-1.example.org");
#line 57 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
	self->priv->_url_1 = _tmp7_;
#line 58 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
	_tmp8_ = g_strdup ("http://www-1.example.org");
#line 58 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
	self->priv->_url_2 = _tmp8_;
#line 60 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
	self->priv->_added_persona = FALSE;
#line 4035 "add-persona.c"
}


static void add_persona_tests_finalize (GObject* obj) {
	AddPersonaTests * self;
#line 26 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (obj, TYPE_ADD_PERSONA_TESTS, AddPersonaTests);
#line 28 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
	_g_main_loop_unref0 (self->priv->_main_loop);
#line 29 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
	_g_object_unref0 (self->priv->_aggregator);
#line 30 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
	_g_free0 (self->priv->_persona_fullname);
#line 31 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
	_g_free0 (self->priv->_persona_nickname);
#line 32 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
	_g_free0 (self->priv->_family_name);
#line 33 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
	_g_free0 (self->priv->_given_name);
#line 34 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
	_g_hash_table_unref0 (self->priv->_properties_found);
#line 35 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
	_g_free0 (self->priv->_persona_iid);
#line 36 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
	_g_object_unref0 (self->priv->_avatar);
#line 37 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
	_g_free0 (self->priv->_birthday);
#line 38 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
	_g_date_time_unref0 (self->priv->_bday);
#line 39 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
	_g_free0 (self->priv->_email_1);
#line 40 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
	_g_free0 (self->priv->_email_2);
#line 41 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
	_g_free0 (self->priv->_im_addr_1);
#line 42 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
	_g_free0 (self->priv->_im_addr_2);
#line 43 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
	_g_free0 (self->priv->_note_1);
#line 44 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
	_g_free0 (self->priv->_phone_1);
#line 45 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
	_g_free0 (self->priv->_phone_2);
#line 46 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
	_g_free0 (self->priv->_title_1);
#line 47 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
	_g_free0 (self->priv->_organisation_1);
#line 48 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
	_g_free0 (self->priv->_role_1);
#line 49 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
	_g_object_unref0 (self->priv->_postal_address_fd);
#line 50 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
	_g_free0 (self->priv->_po_box);
#line 51 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
	_g_free0 (self->priv->_locality);
#line 52 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
	_g_free0 (self->priv->_postal_code);
#line 53 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
	_g_free0 (self->priv->_street);
#line 54 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
	_g_free0 (self->priv->_extension);
#line 55 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
	_g_free0 (self->priv->_country);
#line 56 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
	_g_free0 (self->priv->_region);
#line 57 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
	_g_free0 (self->priv->_url_1);
#line 58 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
	_g_free0 (self->priv->_url_2);
#line 59 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
	_g_object_unref0 (self->priv->_pstore);
#line 26 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
	G_OBJECT_CLASS (add_persona_tests_parent_class)->finalize (obj);
#line 4109 "add-persona.c"
}


GType add_persona_tests_get_type (void) {
	static volatile gsize add_persona_tests_type_id__volatile = 0;
	if (g_once_init_enter (&add_persona_tests_type_id__volatile)) {
		static const GTypeInfo g_define_type_info = { sizeof (AddPersonaTestsClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) add_persona_tests_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (AddPersonaTests), 0, (GInstanceInitFunc) add_persona_tests_instance_init, NULL };
		GType add_persona_tests_type_id;
		add_persona_tests_type_id = g_type_register_static (TRACKER_TEST_TYPE_TEST_CASE, "AddPersonaTests", &g_define_type_info, 0);
		g_once_init_leave (&add_persona_tests_type_id__volatile, add_persona_tests_type_id);
	}
	return add_persona_tests_type_id__volatile;
}


gint _vala_main (gchar** args, int args_length1) {
	gint result = 0;
	AddPersonaTests* tests = NULL;
	AddPersonaTests* _tmp0_ = NULL;
#line 513 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
	g_test_init (&args_length1, &args, NULL);
#line 515 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
	_tmp0_ = add_persona_tests_new ();
#line 515 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
	tests = _tmp0_;
#line 516 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
	folks_test_case_register ((FolksTestCase*) tests);
#line 517 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
	g_test_run ();
#line 518 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
	folks_test_case_final_tear_down ((FolksTestCase*) tests);
#line 520 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
	result = 0;
#line 520 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
	_g_object_unref0 (tests);
#line 520 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
	return result;
#line 4147 "add-persona.c"
}


int main (int argc, char ** argv) {
#if !GLIB_CHECK_VERSION (2,35,0)
	g_type_init ();
#endif
#line 511 "/opt/gnome3/source/folks/tests/tracker/add-persona.vala"
	return _vala_main (argv, argc);
#line 4157 "add-persona.c"
}



